@@ -60,7 +60,7 @@ int swAio_init(void)
     }
     if (swMutex_create(&SwooleAIO.lock, 0) < 0)
     {
-        swWarn("create mutex lock error.");
+        swWarn("create mutex lock error");
         return SW_ERR;
     }
     if (SwooleAIO.thread_num <= 0)
@@ -97,7 +97,7 @@ static int swAio_onCompleted(swReactor *reactor, swEvent *event)
     int n = read(event->fd, events, sizeof(swAio_event*) * SW_AIO_EVENT_NUM);
     if (n < 0)
     {
-        swWarn("read() failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("read() failed");
         return SW_ERR;
     }
     for (i = 0; i < n / sizeof(swAio_event*); i++)
@@ -142,7 +142,7 @@ static int swAio_onTask(swThreadPool *pool, void *task, int task_len)
             }
             else
             {
-                swSysError("sendto swoole_aio_pipe_write failed.");
+                swSysWarn("sendto swoole_aio_pipe_write failed");
             }
         }
         break;
@@ -163,7 +163,7 @@ int swAio_dispatch(swAio_event *_event)
     swAio_event *event = (swAio_event *) sw_malloc(sizeof(swAio_event));
     if (event == NULL)
     {
-        swWarn("malloc failed.");
+        swWarn("malloc failed");
         return SW_ERR;
     }
     memcpy(event, _event, sizeof(swAio_event));
@@ -201,7 +201,7 @@ int swoole_daemon(int nochdir, int noclose)
 
     if (!nochdir && chdir("/") != 0)
     {
-        swWarn("chdir() failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("chdir() failed");
         return -1;
     }
 
@@ -210,14 +210,14 @@ int swoole_daemon(int nochdir, int noclose)
         int fd = open("/dev/null", O_RDWR);
         if (fd < 0)
         {
-            swWarn("open() failed. Error: %s[%d]", strerror(errno), errno);
+            swSysWarn("open() failed");
             return -1;
         }
 
         if (dup2(fd, 0) < 0 || dup2(fd, 1) < 0 || dup2(fd, 2) < 0)
         {
             close(fd);
-            swWarn("dup2() failed. Error: %s[%d]", strerror(errno), errno);
+            swSysWarn("dup2() failed");
             return -1;
         }
 
@@ -227,7 +227,7 @@ int swoole_daemon(int nochdir, int noclose)
     pid = fork();
     if (pid < 0)
     {
-        swWarn("fork() failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("fork() failed");
         return -1;
     }
     if (pid > 0)
@@ -236,7 +236,7 @@ int swoole_daemon(int nochdir, int noclose)
     }
     if (setsid() < 0)
     {
-        swWarn("setsid() failed. Error: %s[%d]", strerror(errno), errno);
+        swSysWarn("setsid() failed");
         return -1;
     }
     return 0;
@@ -247,7 +247,7 @@ void swAio_handler_read(swAio_event *event)
     int ret = -1;
     if (event->lock && flock(event->fd, LOCK_SH) < 0)
     {
-        swSysError("flock(%d, LOCK_SH) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_SH) failed", event->fd);
         event->ret = -1;
         event->error = errno;
         return;
@@ -263,7 +263,7 @@ void swAio_handler_read(swAio_event *event)
     }
     if (event->lock && flock(event->fd, LOCK_UN) < 0)
     {
-        swSysError("flock(%d, LOCK_UN) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_UN) failed", event->fd);
     }
     if (ret < 0)
     {
@@ -276,7 +276,7 @@ void swAio_handler_fgets(swAio_event *event)
 {
     if (event->lock && flock(event->fd, LOCK_SH) < 0)
     {
-        swSysError("flock(%d, LOCK_SH) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_SH) failed", event->fd);
         event->ret = -1;
         event->error = errno;
         return;
@@ -293,7 +293,7 @@ void swAio_handler_fgets(swAio_event *event)
 
     if (event->lock && flock(event->fd, LOCK_UN) < 0)
     {
-        swSysError("flock(%d, LOCK_UN) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_UN) failed", event->fd);
     }
 }
 
@@ -303,7 +303,7 @@ void swAio_handler_read_file(swAio_event *event)
     int fd = open(event->req, O_RDONLY);
     if (fd < 0)
     {
-        swSysError("open(%s, O_RDONLY) failed.", (char * )event->req);
+        swSysWarn("open(%s, O_RDONLY) failed", (char * )event->req);
         event->ret = ret;
         event->error = errno;
         return;
@@ -311,7 +311,7 @@ void swAio_handler_read_file(swAio_event *event)
     struct stat file_stat;
     if (fstat(fd, &file_stat) < 0)
     {
-        swSysError("fstat(%s) failed.", (char * )event->req);
+        swSysWarn("fstat(%s) failed", (char * )event->req);
         _error: close(fd);
         event->ret = ret;
         event->error = errno;
@@ -328,7 +328,7 @@ void swAio_handler_read_file(swAio_event *event)
      */
     if (event->lock && flock(fd, LOCK_SH) < 0)
     {
-        swSysError("flock(%d, LOCK_SH) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_SH) failed", event->fd);
         goto _error;
     }
     /**
@@ -360,7 +360,7 @@ void swAio_handler_read_file(swAio_event *event)
      */
     if (event->lock && flock(fd, LOCK_UN) < 0)
     {
-        swSysError("flock(%d, LOCK_UN) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_UN) failed", event->fd);
     }
     close(fd);
     event->error = 0;
@@ -372,14 +372,14 @@ void swAio_handler_write_file(swAio_event *event)
     int fd = open(event->req, event->flags, 0644);
     if (fd < 0)
     {
-        swSysError("open(%s, %d) failed.", (char * )event->req, event->flags);
+        swSysWarn("open(%s, %d) failed", (char * )event->req, event->flags);
         event->ret = ret;
         event->error = errno;
         return;
     }
     if (event->lock && flock(fd, LOCK_EX) < 0)
     {
-        swSysError("flock(%d, LOCK_EX) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_EX) failed", event->fd);
         event->ret = ret;
         event->error = errno;
         close(fd);
@@ -390,12 +390,12 @@ void swAio_handler_write_file(swAio_event *event)
     {
         if (fsync(fd) < 0)
         {
-            swSysError("fsync(%d) failed.", event->fd);
+            swSysWarn("fsync(%d) failed", event->fd);
         }
     }
     if (event->lock && flock(fd, LOCK_UN) < 0)
     {
-        swSysError("flock(%d, LOCK_UN) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_UN) failed", event->fd);
     }
     close(fd);
     event->ret = written;
@@ -407,7 +407,7 @@ void swAio_handler_write(swAio_event *event)
     int ret = -1;
     if (event->lock && flock(event->fd, LOCK_EX) < 0)
     {
-        swSysError("flock(%d, LOCK_EX) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_EX) failed", event->fd);
         return;
     }
     if (event->offset == 0)
@@ -422,12 +422,12 @@ void swAio_handler_write(swAio_event *event)
     {
         if (fsync(event->fd) < 0)
         {
-            swSysError("fsync(%d) failed.", event->fd);
+            swSysWarn("fsync(%d) failed", event->fd);
         }
     }
     if (event->lock && flock(event->fd, LOCK_UN) < 0)
     {
-        swSysError("flock(%d, LOCK_UN) failed.", event->fd);
+        swSysWarn("flock(%d, LOCK_UN) failed", event->fd);
     }
     if (ret < 0)
     {
