@@ -25,7 +25,7 @@ int swMsgQueue_free(swMsgQueue *q)
 {
     if (msgctl(q->msg_id, IPC_RMID, 0) < 0)
     {
-        swSysError("msgctl(%d, IPC_RMID) failed.", q->msg_id);
+        swSysWarn("msgctl(%d, IPC_RMID) failed", q->msg_id);
         return SW_ERR;
     }
     return SW_OK;
@@ -53,7 +53,7 @@ int swMsgQueue_create(swMsgQueue *q, int blocking, key_t msg_key, int perms)
     msg_id = msgget(msg_key, IPC_CREAT | perms);
     if (msg_id < 0)
     {
-        swSysError("msgget() failed.");
+        swSysWarn("msgget() failed");
         return SW_ERR;
     }
     else
@@ -75,7 +75,7 @@ int swMsgQueue_pop(swMsgQueue *q, swQueue_data *data, int length)
         SwooleG.error = errno;
         if (errno != ENOMSG && errno != EINTR)
         {
-            swSysError("msgrcv(%d, %d, %ld) failed.", q->msg_id, length, data->mtype);
+            swSysWarn("msgrcv(%d, %d, %ld) failed", q->msg_id, length, data->mtype);
         }
     }
     return ret;
@@ -101,7 +101,7 @@ int swMsgQueue_push(swMsgQueue *q, swQueue_data *in, int length)
             }
             else
             {
-                swSysError("msgsnd(%d, %d, %ld) failed.", q->msg_id, length, in->mtype);
+                swSysWarn("msgsnd(%d, %d, %ld) failed", q->msg_id, length, in->mtype);
                 return -1;
             }
         }
@@ -138,7 +138,7 @@ int swMsgQueue_set_capacity(swMsgQueue *q, int queue_bytes)
     __stat.msg_qbytes = queue_bytes;
     if (msgctl(q->msg_id, IPC_SET, &__stat))
     {
-        swSysError("msgctl(msqid=%d, IPC_SET, msg_qbytes=%d) failed.", q->msg_id, queue_bytes);
+        swSysWarn("msgctl(msqid=%d, IPC_SET, msg_qbytes=%d) failed", q->msg_id, queue_bytes);
         return -1;
     }
     return 0;
