@@ -86,7 +86,7 @@ static int swReactorPoll_add(swReactor *reactor, int fd, int fdtype)
 {
     if (swReactorPoll_exist(reactor, fd))
     {
-        swWarn("fd#%d is already exists.", fd);
+        swWarn("fd#%d is already exists", fd);
         return SW_ERR;
     }
 
@@ -219,7 +219,7 @@ static int swReactorPoll_wait(swReactor *reactor, struct timeval *timeo)
         {
             if (swReactor_error(reactor) < 0)
             {
-                swWarn("poll error. Error: %s[%d]", strerror(errno), errno);
+                swSysWarn("poll error");
             }
             continue;
         }
@@ -248,7 +248,7 @@ static int swReactorPoll_wait(swReactor *reactor, struct timeval *timeo)
                     ret = handle(reactor, &event);
                     if (ret < 0)
                     {
-                        swWarn("poll[POLLIN] handler failed. fd=%d. Error: %s[%d]", event.fd, strerror(errno), errno);
+                        swSysWarn("poll[POLLIN] handler failed. fd=%d", event.fd);
                     }
                 }
                 //out
@@ -258,7 +258,7 @@ static int swReactorPoll_wait(swReactor *reactor, struct timeval *timeo)
                     ret = handle(reactor, &event);
                     if (ret < 0)
                     {
-                        swWarn("poll[POLLOUT] handler failed. fd=%d. Error: %s[%d]", event.fd, strerror(errno), errno);
+                        swSysWarn("poll[POLLOUT] handler failed. fd=%d", event.fd);
                     }
                 }
                 //error
@@ -273,7 +273,7 @@ static int swReactorPoll_wait(swReactor *reactor, struct timeval *timeo)
                     ret = handle(reactor, &event);
                     if (ret < 0)
                     {
-                        swWarn("poll[POLLERR] handler failed. fd=%d. Error: %s[%d]", event.fd, strerror(errno), errno);
+                        swSysWarn("poll[POLLERR] handler failed. fd=%d", event.fd);
                     }
                 }
                 if (!event.socket->removed && (event.socket->events & SW_EVENT_ONCE))
