@@ -23,7 +23,6 @@
 #include <grp.h>
 
 static int swWorker_onPipeReceive(swReactor *reactor, swEvent *event);
-static void swWorker_onTimeout(swTimer *timer, swTimer_node *tnode);
 static int swWorker_onStreamAccept(swReactor *reactor, swEvent *event);
 static int swWorker_onStreamRead(swReactor *reactor, swEvent *event);
 static int swWorker_onStreamPackage(swConnection *conn, char *data, uint32_t length);
@@ -146,8 +145,7 @@ static int swWorker_onStreamAccept(swReactor *reactor, swEvent *event)
         case EAGAIN:
             return SW_OK;
         default:
-            swoole_error_log(SW_LOG_ERROR, SW_ERROR_SYSTEM_CALL_FAIL, "accept() failed. Error: %s[%d]", strerror(errno),
-                    errno);
+            swSysWarn("accept() failed");
             return SW_OK;
         }
     }
@@ -410,7 +408,7 @@ void swWorker_onStart(swServer *serv)
             group = getgrnam(SwooleG.group);
             if (!group)
             {
-                swWarn("get group [%s] info failed.", SwooleG.group);
+                swWarn("get group [%s] info failed", SwooleG.group);
             }
         }
         //get user info
@@ -419,7 +417,7 @@ void swWorker_onStart(swServer *serv)
             passwd = getpwnam(SwooleG.user);
             if (!passwd)
             {
-                swWarn("get user [%s] info failed.", SwooleG.user);
+                swWarn("get user [%s] info failed", SwooleG.user);
             }
         }
         //chroot
@@ -427,7 +425,7 @@ void swWorker_onStart(swServer *serv)
         {
             if (0 > chroot(SwooleG.chroot))
             {
-                swSysError("chroot to [%s] failed.", SwooleG.chroot);
+                swSysWarn("chroot to [%s] failed", SwooleG.chroot);
             }
         }
         //set process group
@@ -435,7 +433,7 @@ void swWorker_onStart(swServer *serv)
         {
             if (setgid(group->gr_gid) < 0)
             {
-                swSysError("setgid to [%s] failed.", SwooleG.group);
+                swSysWarn("setgid to [%s] failed", SwooleG.group);
             }
         }
         //set process user
@@ -443,7 +441,7 @@ void swWorker_onStart(swServer *serv)
         {
             if (setuid(passwd->pw_uid) < 0)
             {
-                swSysError("setuid to [%s] failed.", SwooleG.user);
+                swSysWarn("setuid to [%s] failed", SwooleG.user);
             }
         }
     }
@@ -472,6 +470,13 @@ void swWorker_onStart(swServer *serv)
     if (serv->factory_mode == SW_MODE_PROCESS)
     {
         sw_shm_protect(serv->session_list, PROT_READ);
+        /**
+         * Use only the first block of pipe_buffer memory in worker process
+         */
+        for (i = 1; i < serv->reactor_num; i++)
+        {
+            sw_free(serv->pipe_buffers[i]);
+        }
     }
 
 #ifdef HAVE_SIGNALFD
@@ -571,14 +576,6 @@ void swWorker_stop(swWorker *worker)
     swWorker_try_to_exit();
 }
 
-static void swWorker_onTimeout(swTimer *timer, swTimer_node *tnode)
-{
-    SwooleG.running = 0;
-    SwooleG.main_reactor->running = 0;
-    SwooleWG.exit_timer = nullptr;
-    swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_WORKER_EXIT_TIMEOUT, "worker exit timeout, forced to terminate.");
-}
-
 void swWorker_try_to_exit()
 {
     swWorker *worker = SwooleWG.worker;
@@ -602,12 +599,6 @@ void swWorker_try_to_exit()
 
     uint8_t call_worker_exit_func = 0;
 
-    if (SwooleWG.exit_timer)
-    {
-        swTimer_del(&SwooleG.timer, SwooleWG.exit_timer);
-        SwooleWG.exit_timer = nullptr;
-    }
-
     while (1)
     {
         if (swReactor_empty(SwooleG.main_reactor))
@@ -623,14 +614,21 @@ void swWorker_try_to_exit()
                 call_worker_exit_func = 1;
                 continue;
             }
-            int remaining_time = serv->max_wait_time - (serv->gs->now - SwooleWG.exit_time);
+            int remaining_time = serv->max_wait_time - (time(NULL) - SwooleWG.exit_time);
             if (remaining_time <= 0)
             {
-                swWorker_onTimeout(nullptr, nullptr);
+                SwooleG.running = 0;
+                SwooleG.main_reactor->running = 0;
+                swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_WORKER_EXIT_TIMEOUT,
+                        "worker exit timeout, forced to terminate");
             }
             else
             {
-                SwooleWG.exit_timer = swTimer_add(&SwooleG.timer, (long) (remaining_time * 1000), 0, NULL, swWorker_onTimeout);
+                int timeout_msec = remaining_time * 1000;
+                if (SwooleG.main_reactor->timeout_msec < 0 || SwooleG.main_reactor->timeout_msec > timeout_msec)
+                {
+                    SwooleG.main_reactor->timeout_msec = timeout_msec;
+                }
             }
         }
         break;
@@ -662,10 +660,8 @@ void swWorker_clean(void)
 /**
  * main loop [Worker]
  */
-int swWorker_loop(swFactory *factory, int worker_id)
+int swWorker_loop(swServer *serv, int worker_id)
 {
-    swServer *serv = (swServer *) factory->ptr;
-
     //worker_id
     SwooleWG.id = worker_id;
 
@@ -675,13 +671,13 @@ int swWorker_loop(swFactory *factory, int worker_id)
     SwooleG.main_reactor = (swReactor *) sw_malloc(sizeof(swReactor));
     if (SwooleG.main_reactor == NULL)
     {
-        swError("[Worker] malloc for reactor failed.");
+        swError("[Worker] malloc for reactor failed");
         return SW_ERR;
     }
 
     if (swReactor_create(SwooleG.main_reactor, SW_REACTOR_MAXEVENTS) < 0)
     {
-        swError("[Worker] create worker_reactor failed.");
+        swError("[Worker] create worker_reactor failed");
         return SW_ERR;
     }
 
@@ -718,6 +714,10 @@ int swWorker_loop(swFactory *factory, int worker_id)
         serv->stream_protocol.package_max_length = INT_MAX;
         serv->stream_protocol.onPackage = swWorker_onStreamPackage;
         serv->buffer_pool = swLinkedList_new(0, NULL);
+        if (serv->buffer_pool == nullptr)
+        {
+            return SW_ERR;
+        }
     }
 
     swWorker_onStart(serv);
@@ -755,21 +755,21 @@ int swWorker_send2reactor(swServer *serv, swEventData *ev_data, size_t sendn, in
  */
 static int swWorker_onPipeReceive(swReactor *reactor, swEvent *event)
 {
-    swEventData task;
     swServer *serv = (swServer *) reactor->ptr;
     swFactory *factory = &serv->factory;
+    swPipeBuffer *buffer = serv->pipe_buffers[0];
     int ret;
 
     read_from_pipe:
 
-    if (read(event->fd, &task, sizeof(task)) > 0)
+    if (read(event->fd, buffer, serv->ipc_max_size) > 0)
     {
-        ret = swWorker_onTask(factory, &task);
+        ret = swWorker_onTask(factory, (swEventData *) buffer);
 #ifndef SW_WORKER_RECV_AGAIN
         /**
          * Big package
          */
-        if (task.info.flags & SW_EVENT_DATA_CHUNK)
+        if (buffer->info.flags & SW_EVENT_DATA_CHUNK)
 #endif
         {
             //no data
