@@ -68,16 +68,13 @@ enum http_upload_errno
     HTTP_UPLOAD_ERR_CANT_WRITE,
 };
 
-static zend_class_entry swoole_http_server_ce;
-zend_class_entry *swoole_http_server_ce_ptr;
+zend_class_entry *swoole_http_server_ce;
 zend_object_handlers swoole_http_server_handlers;
 
-static zend_class_entry swoole_http_response_ce;
-zend_class_entry *swoole_http_response_ce_ptr;
+zend_class_entry *swoole_http_response_ce;
 static zend_object_handlers swoole_http_response_handlers;
 
-static zend_class_entry swoole_http_request_ce;
-zend_class_entry *swoole_http_request_ce_ptr;
+zend_class_entry *swoole_http_request_ce;
 static zend_object_handlers swoole_http_request_handlers;
 
 static int http_request_on_path(swoole_http_parser *parser, const char *at, size_t length);
@@ -95,8 +92,6 @@ static int multipart_body_on_header_complete(multipart_parser* p);
 static int multipart_body_on_data_end(multipart_parser* p);
 
 static http_context* http_get_context(zval *zobject, int check_end);
-
-static void http_parse_cookie(zval *array, const char *at, size_t length);
 static void http_build_header(http_context *, zval *zobject, swString *response, int body_length);
 
 static inline void http_header_key_format(char *key, int length)
@@ -178,6 +173,7 @@ static PHP_METHOD(swoole_http_response, detach);
 static PHP_METHOD(swoole_http_response, create);
 #ifdef SW_USE_HTTP2
 static PHP_METHOD(swoole_http_response, trailer);
+static PHP_METHOD(swoole_http_response, ping);
 #endif
 static PHP_METHOD(swoole_http_response, status);
 static PHP_METHOD(swoole_http_response, __destruct);
@@ -261,7 +257,6 @@ ZEND_END_ARG_INFO()
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_http_response_trailer, 0, 0, 2)
     ZEND_ARG_INFO(0, key)
     ZEND_ARG_INFO(0, value)
-    ZEND_ARG_INFO(0, ucwords)
 ZEND_END_ARG_INFO()
 #endif
 
@@ -340,6 +335,7 @@ const zend_function_entry swoole_http_response_methods[] =
     PHP_ME(swoole_http_response, header, arginfo_swoole_http_response_header, ZEND_ACC_PUBLIC)
 #ifdef SW_USE_HTTP2
     PHP_ME(swoole_http_response, trailer, arginfo_swoole_http_response_trailer, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_http_response, ping, arginfo_swoole_http_void, ZEND_ACC_PUBLIC)
 #endif
     PHP_ME(swoole_http_response, write, arginfo_swoole_http_response_write, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_http_response, end, arginfo_swoole_http_response_end, ZEND_ACC_PUBLIC)
@@ -390,7 +386,7 @@ int swoole_http_parse_form_data(http_context *ctx, const char *boundary_str, int
     multipart_parser *mt_parser = multipart_parser_init(boundary_str, boundary_len, &mt_parser_settings);
     if (!mt_parser)
     {
-        swoole_php_fatal_error(E_WARNING, "multipart_parser_init() failed.");
+        swoole_php_fatal_error(E_WARNING, "multipart_parser_init() failed");
         return SW_ERR;
     }
 
@@ -400,7 +396,7 @@ int swoole_http_parse_form_data(http_context *ctx, const char *boundary_str, int
     return SW_OK;
 }
 
-static void http_parse_cookie(zval *array, const char *at, size_t length)
+void swoole_http_parse_cookie(zval *array, const char *at, size_t length)
 {
     char keybuf[SW_HTTP_COOKIE_KEYLEN];
     char valbuf[SW_HTTP_COOKIE_VALLEN];
@@ -419,7 +415,7 @@ static void http_parse_cookie(zval *array, const char *at, size_t length)
             klen = i - j + 1;
             if (klen >= SW_HTTP_COOKIE_KEYLEN)
             {
-                swWarn("cookie[%.*s...] name length %d is exceed the max name len %d.", 8, (char *) at + j, klen, SW_HTTP_COOKIE_KEYLEN);
+                swWarn("cookie[%.*s...] name length %d is exceed the max name len %d", 8, (char *) at + j, klen, SW_HTTP_COOKIE_KEYLEN);
                 return;
             }
             memcpy(keybuf, (char *) at + j, klen - 1);
@@ -433,7 +429,7 @@ static void http_parse_cookie(zval *array, const char *at, size_t length)
             vlen = i - j;
             if (vlen >= SW_HTTP_COOKIE_VALLEN)
             {
-            swWarn("cookie[%s]'s value[v=%.*s...] length %d is exceed the max value len %d.", keybuf, 8, (char *) at + j, vlen, SW_HTTP_COOKIE_VALLEN);
+                swWarn("cookie[%s]'s value[v=%.*s...] length %d is exceed the max value len %d", keybuf, 8, (char *) at + j, vlen, SW_HTTP_COOKIE_VALLEN);
                 return;
             }
             memcpy(valbuf, (char *) at + j, vlen);
@@ -467,13 +463,13 @@ static void http_parse_cookie(zval *array, const char *at, size_t length)
         vlen = i - j;
         if (klen >= SW_HTTP_COOKIE_KEYLEN)
         {
-            swWarn("cookie[%.*s...] name length %d is exceed the max name len %d.", 8, keybuf, klen, SW_HTTP_COOKIE_KEYLEN);
+            swWarn("cookie[%.*s...] name length %d is exceed the max name len %d", 8, keybuf, klen, SW_HTTP_COOKIE_KEYLEN);
             return;
         }
         keybuf[klen - 1] = 0;
         if (vlen >= SW_HTTP_COOKIE_VALLEN)
         {
-            swWarn("cookie[%s]'s value[v=%.*s...] length %d is exceed the max value len %d.", keybuf, 8, (char *) at + j, vlen, SW_HTTP_COOKIE_VALLEN);
+            swWarn("cookie[%s]'s value[v=%.*s...] length %d is exceed the max value len %d", keybuf, 8, (char *) at + j, vlen, SW_HTTP_COOKIE_VALLEN);
             return;
         }
         memcpy(valbuf, (char *) at + j, vlen);
@@ -496,11 +492,11 @@ static int http_request_on_header_value(swoole_http_parser *parser, const char *
     size_t header_len = ctx->current_header_name_len;
     char *header_name = zend_str_tolower_dup(ctx->current_header_name, header_len);
 
-    if (strncmp(header_name, "cookie", header_len) == 0)
+    if (SwooleG.serv->http_parse_cookie && strncmp(header_name, "cookie", header_len) == 0)
     {
         zval *zcookie;
         swoole_http_server_array_init(cookie, request);
-        http_parse_cookie(zcookie, at, length);
+        swoole_http_parse_cookie(zcookie, at, length);
         efree(header_name);
         return 0;
     }
@@ -509,7 +505,7 @@ static int http_request_on_header_value(swoole_http_parser *parser, const char *
         swConnection *conn = swWorker_get_connection(SwooleG.serv, ctx->fd);
         if (!conn)
         {
-            swWarn("connection[%d] is closed.", ctx->fd);
+            swWarn("connection[%d] is closed", ctx->fd);
             return SW_ERR;
         }
         swListenPort *port = (swListenPort *) SwooleG.serv->connection_list[conn->from_fd].object;
@@ -547,7 +543,7 @@ static int http_request_on_header_value(swoole_http_parser *parser, const char *
                 }
                 if (boundary_len <= 0)
                 {
-                    swWarn("invalid multipart/form-data body fd:%d.", ctx->fd);
+                    swWarn("invalid multipart/form-data body fd:%d", ctx->fd);
                     return 0;
                 }
                 // trim '"'
@@ -600,7 +596,7 @@ static int multipart_body_on_header_value(multipart_parser* p, const char *at, s
     if (ctx->input_var_num > PG(max_input_vars))
     {
         swoole_php_error(E_WARNING, "Input variables exceeded " ZEND_LONG_FMT ". "
-                "To increase the limit change max_input_vars in php.ini.", PG(max_input_vars));
+                "To increase the limit change max_input_vars in php.ini", PG(max_input_vars));
         return SW_OK;
     }
     else
@@ -621,7 +617,7 @@ static int multipart_body_on_header_value(multipart_parser* p, const char *at, s
 
         zval tmp_array;
         array_init(&tmp_array);
-        http_parse_cookie(&tmp_array, (char *) at + sizeof("form-data;") - 1, length - sizeof("form-data;") + 1);
+        swoole_http_parse_cookie(&tmp_array, (char *) at + sizeof("form-data;") - 1, length - sizeof("form-data;") + 1);
 
         zval *form_name;
         if (!(form_name = zend_hash_str_find(Z_ARRVAL(tmp_array), ZEND_STRL("name"))))
@@ -631,7 +627,7 @@ static int multipart_body_on_header_value(multipart_parser* p, const char *at, s
 
         if (Z_STRLEN_P(form_name) >= SW_HTTP_COOKIE_KEYLEN)
         {
-            swWarn("form_name[%s] is too large.", Z_STRVAL_P(form_name));
+            swWarn("form_name[%s] is too large", Z_STRVAL_P(form_name));
             return SW_OK;
         }
 
@@ -651,7 +647,7 @@ static int multipart_body_on_header_value(multipart_parser* p, const char *at, s
         {
             if (Z_STRLEN_P(filename) >= SW_HTTP_COOKIE_KEYLEN)
             {
-                swWarn("filename[%s] is too large.", Z_STRVAL_P(filename));
+                swWarn("filename[%s] is too large", Z_STRVAL_P(filename));
                 return SW_OK;
             }
             ctx->current_input_name = estrndup(tmp, value_len);
@@ -707,7 +703,7 @@ static int multipart_body_on_data(multipart_parser* p, const char *at, size_t le
         fclose((FILE *) p->fp);
         p->fp = NULL;
 
-        swWarn("write upload file failed. Error %s[%d]", strerror(errno), errno);
+        swSysWarn("write upload file failed");
     }
     return 0;
 }
@@ -759,14 +755,14 @@ static int multipart_body_on_header_complete(multipart_parser* p)
     if (fp == NULL)
     {
         add_assoc_long(multipart_header, "error", HTTP_UPLOAD_ERR_NO_TMP_DIR);
-        swWarn("fopen(%s) failed. Error %s[%d]", file_path, strerror(errno), errno);
+        swSysWarn("fopen(%s) failed", file_path);
         return 0;
     }
 
     p->fp = fp;
     add_assoc_string(multipart_header, "tmp_name", file_path);
 
-    zval *ztmpfiles = sw_zend_read_property(swoole_http_request_ce_ptr, zrequest_object, ZEND_STRL("tmpfiles"), 1);
+    zval *ztmpfiles = sw_zend_read_property(swoole_http_request_ce, zrequest_object, ZEND_STRL("tmpfiles"), 1);
     if (ztmpfiles == NULL || ZVAL_IS_NULL(ztmpfiles))
     {
         swoole_http_server_array_init(tmpfiles, request);
@@ -787,7 +783,7 @@ static int multipart_body_on_data_end(multipart_parser* p)
     zval *zrequest_object = ctx->request.zobject;
     if (ctx->current_form_data_name)
     {
-        zval *zpost = sw_zend_read_property(swoole_http_request_ce_ptr, zrequest_object, ZEND_STRL("post"), 1);
+        zval *zpost = sw_zend_read_property(swoole_http_request_ce, zrequest_object, ZEND_STRL("post"), 1);
         if (ZVAL_IS_NULL(zpost))
         {
             swoole_http_server_array_init(post, request);
@@ -865,7 +861,7 @@ static int http_request_on_body(swoole_http_parser *parser, const char *at, size
         size_t n = multipart_parser_execute(multipart_parser, c, length);
         if (n != length)
         {
-            swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_INVALID_REQUEST, "parse multipart body failed, n=%zu.", n);
+            swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_INVALID_REQUEST, "parse multipart body failed, n=%zu", n);
         }
     }
 
@@ -909,7 +905,7 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
     swConnection *conn = swServer_connection_verify_no_ssl(serv, fd);
     if (!conn)
     {
-        swoole_error_log(SW_LOG_NOTICE, SW_ERROR_SESSION_NOT_EXIST, "connection[%d] is closed.", fd);
+        swoole_error_log(SW_LOG_NOTICE, SW_ERROR_SESSION_NOT_EXIST, "connection[%d] is closed", fd);
         return SW_ERR;
     }
 
@@ -927,7 +923,7 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
 #ifdef SW_USE_HTTP2
     if (conn->http2_stream)
     {
-        return swoole_http2_onFrame(conn, req);
+        return swoole_http2_server_onFrame(conn, req);
     }
 #endif
 
@@ -952,7 +948,7 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
     if (n < 0)
     {
         sw_zval_free(zdata);
-        swWarn("swoole_http_parser_execute failed.");
+        swWarn("swoole_http_parser_execute failed");
         if (conn->websocket_status == WEBSOCKET_STATUS_CONNECTION)
         {
             return serv->close(serv, fd, 1);
@@ -967,10 +963,11 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
         ctx->keepalive = swoole_http_should_keep_alive(parser);
 
         add_assoc_string(zserver, "request_method", (char *) http_get_method_name(parser->method));
+        add_assoc_stringl_ex(zserver, ZEND_STRL("request_uri"), ctx->request.path, ctx->request.path_len);
 
+        // path_info should be decoded
         zend_string * zstr_path = zend_string_init(ctx->request.path, ctx->request.path_len, 0);
-        add_assoc_str_ex(zserver, ZEND_STRL("request_uri"), zstr_path);
-        GC_ADDREF(zstr_path);
+        ZSTR_LEN(zstr_path) = php_url_decode(ZSTR_VAL(zstr_path), ZSTR_LEN(zstr_path));
         add_assoc_str_ex(zserver, ZEND_STRL("path_info"), zstr_path);
 
         add_assoc_long_ex(zserver, ZEND_STRL("request_time"), serv->gs->now);
@@ -980,7 +977,7 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
         if (!conn)
         {
             sw_zval_free(zdata);
-            swWarn("connection[%d] is closed.", fd);
+            swWarn("connection[%d] is closed", fd);
             return SW_ERR;
         }
 
@@ -1023,7 +1020,7 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
         {
             if (PHPCoroutine::create(fci_cache, 2, args) < 0)
             {
-                swoole_php_error(E_WARNING, "create Http onRequest coroutine error.");
+                swoole_php_error(E_WARNING, "create Http onRequest coroutine error");
 #ifdef SW_HTTP_SERVICE_UNAVAILABLE_PACKET
                 serv->send(serv, fd, (char *) SW_STRL(SW_HTTP_SERVICE_UNAVAILABLE_PACKET));
 #endif
@@ -1035,7 +1032,7 @@ int php_swoole_http_onReceive(swServer *serv, swEventData *req)
             zval _retval, *retval = &_retval;
             if (sw_call_user_function_fast_ex(NULL, fci_cache, retval, 2, args) == FAILURE)
             {
-                swoole_php_error(E_WARNING, "Http onRequest handler error.");
+                swoole_php_error(E_WARNING, "Http onRequest handler error");
             }
             zval_ptr_dtor(retval);
         }
@@ -1058,7 +1055,7 @@ void php_swoole_http_onClose(swServer *serv, swDataHead *ev)
 #ifdef SW_USE_HTTP2
     if (conn->http2_stream)
     {
-        swoole_http2_free(conn);
+        swoole_http2_server_session_free(conn);
     }
 #endif
     php_swoole_onClose(serv, ev);
@@ -1066,42 +1063,42 @@ void php_swoole_http_onClose(swServer *serv, swDataHead *ev)
 
 void swoole_http_server_init(int module_number)
 {
-    SWOOLE_INIT_CLASS_ENTRY_EX(swoole_http_server, "Swoole\\Http\\Server", "swoole_http_server", NULL, NULL, swoole_server);
-    SWOOLE_SET_CLASS_SERIALIZABLE(swoole_http_server, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SWOOLE_SET_CLASS_CLONEABLE(swoole_http_server, zend_class_clone_deny);
-    SWOOLE_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_http_server, zend_class_unset_property_deny);
+    SW_INIT_CLASS_ENTRY_EX(swoole_http_server, "Swoole\\Http\\Server", "swoole_http_server", NULL, NULL, swoole_server);
+    SW_SET_CLASS_SERIALIZABLE(swoole_http_server, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_CLONEABLE(swoole_http_server, zend_class_clone_deny);
+    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_http_server, zend_class_unset_property_deny);
 
-    zend_declare_property_null(swoole_http_server_ce_ptr, ZEND_STRL("onRequest"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_server_ce_ptr, ZEND_STRL("onHandshake"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_server_ce_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_server_ce, ZEND_STRL("onRequest"), ZEND_ACC_PRIVATE);
 
-    SWOOLE_INIT_CLASS_ENTRY(swoole_http_request, "Swoole\\Http\\Request", "swoole_http_request", NULL, swoole_http_request_methods);
-    SWOOLE_SET_CLASS_SERIALIZABLE(swoole_http_request, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SWOOLE_SET_CLASS_CLONEABLE(swoole_http_request, zend_class_clone_deny);
-    SWOOLE_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_http_request, zend_class_unset_property_deny);
+    SW_INIT_CLASS_ENTRY(swoole_http_request, "Swoole\\Http\\Request", "swoole_http_request", NULL, swoole_http_request_methods);
+    SW_SET_CLASS_SERIALIZABLE(swoole_http_request, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_CLONEABLE(swoole_http_request, zend_class_clone_deny);
+    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_http_request, zend_class_unset_property_deny);
 
-    zend_declare_property_long(swoole_http_request_ce_ptr, ZEND_STRL("fd"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_http_request_ce, ZEND_STRL("fd"), 0, ZEND_ACC_PUBLIC);
 #ifdef SW_USE_HTTP2
-    zend_declare_property_long(swoole_http_request_ce_ptr, ZEND_STRL("streamId"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_http_request_ce, ZEND_STRL("streamId"), 0, ZEND_ACC_PUBLIC);
 #endif
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("header"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("server"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("request"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("cookie"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("get"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("files"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("post"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_request_ce_ptr, ZEND_STRL("tmpfiles"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("header"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("server"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("request"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("cookie"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("get"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("files"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("post"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_request_ce, ZEND_STRL("tmpfiles"), ZEND_ACC_PUBLIC);
 
-    SWOOLE_INIT_CLASS_ENTRY(swoole_http_response, "Swoole\\Http\\Response", "swoole_http_response", NULL, swoole_http_response_methods);
-    SWOOLE_SET_CLASS_SERIALIZABLE(swoole_http_response, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SWOOLE_SET_CLASS_CLONEABLE(swoole_http_response, zend_class_clone_deny);
-    SWOOLE_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_http_response, zend_class_unset_property_deny);
+    SW_INIT_CLASS_ENTRY(swoole_http_response, "Swoole\\Http\\Response", "swoole_http_response", NULL, swoole_http_response_methods);
+    SW_SET_CLASS_SERIALIZABLE(swoole_http_response, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_CLONEABLE(swoole_http_response, zend_class_clone_deny);
+    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_http_response, zend_class_unset_property_deny);
 
-    zend_declare_property_long(swoole_http_response_ce_ptr, ZEND_STRL("fd"), 0,  ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_response_ce_ptr, ZEND_STRL("header"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_response_ce_ptr, ZEND_STRL("cookie"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_http_response_ce_ptr, ZEND_STRL("trailer"), ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_http_response_ce, ZEND_STRL("fd"), 0,  ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_response_ce, ZEND_STRL("header"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_http_response_ce, ZEND_STRL("cookie"), ZEND_ACC_PUBLIC);
+#ifdef SW_USE_HTTP2
+    zend_declare_property_null(swoole_http_response_ce, ZEND_STRL("trailer"), ZEND_ACC_PUBLIC);
+#endif
 }
 
 http_context* swoole_http_context_new(int fd)
@@ -1109,7 +1106,7 @@ http_context* swoole_http_context_new(int fd)
     http_context *ctx = (http_context *) emalloc(sizeof(http_context));
     if (!ctx)
     {
-        swoole_error_log(SW_LOG_ERROR, SW_ERROR_MALLOC_FAIL, "emalloc(%ld) failed.", sizeof(http_context));
+        swoole_error_log(SW_LOG_ERROR, SW_ERROR_MALLOC_FAIL, "emalloc(%ld) failed", sizeof(http_context));
         return NULL;
     }
     bzero(ctx, sizeof(http_context));
@@ -1117,18 +1114,18 @@ http_context* swoole_http_context_new(int fd)
     zval *zrequest_object;
     zrequest_object = &ctx->request._zobject;
     ctx->request.zobject = zrequest_object;
-    object_init_ex(zrequest_object, swoole_http_request_ce_ptr);
+    object_init_ex(zrequest_object, swoole_http_request_ce);
     swoole_set_object(zrequest_object, ctx);
 
     zval *zresponse_object;
     zresponse_object = &ctx->response._zobject;
     ctx->response.zobject = zresponse_object;
-    object_init_ex(zresponse_object, swoole_http_response_ce_ptr);
+    object_init_ex(zresponse_object, swoole_http_response_ce);
     swoole_set_object(zresponse_object, ctx);
 
     //socket fd
-    zend_update_property_long(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("fd"), fd);
-    zend_update_property_long(swoole_http_request_ce_ptr, zrequest_object, ZEND_STRL("fd"), fd);
+    zend_update_property_long(swoole_http_response_ce, zresponse_object, ZEND_STRL("fd"), fd);
+    zend_update_property_long(swoole_http_request_ce, zrequest_object, ZEND_STRL("fd"), fd);
 
 #if PHP_MEMORY_DEBUG
     php_vmstat.new_http_request ++;
@@ -1167,147 +1164,30 @@ void swoole_http_context_free(http_context *ctx)
     efree(ctx);
 }
 
-static const char *http_status_message(int code)
-{
-    switch (code)
-    {
-    case 100:
-        return "100 Continue";
-    case 101:
-        return "101 Switching Protocols";
-    case 201:
-        return "201 Created";
-    case 202:
-        return "202 Accepted";
-    case 203:
-        return "203 Non-Authoritative Information";
-    case 204:
-        return "204 No Content";
-    case 205:
-        return "205 Reset Content";
-    case 206:
-        return "206 Partial Content";
-    case 207:
-        return "207 Multi-Status";
-    case 208:
-        return "208 Already Reported";
-    case 226:
-        return "226 IM Used";
-    case 300:
-        return "300 Multiple Choices";
-    case 301:
-        return "301 Moved Permanently";
-    case 302:
-        return "302 Found";
-    case 303:
-        return "303 See Other";
-    case 304:
-        return "304 Not Modified";
-    case 305:
-        return "305 Use Proxy";
-    case 307:
-        return "307 Temporary Redirect";
-    case 400:
-        return "400 Bad Request";
-    case 401:
-        return "401 Unauthorized";
-    case 402:
-        return "402 Payment Required";
-    case 403:
-        return "403 Forbidden";
-    case 404:
-        return "404 Not Found";
-    case 405:
-        return "405 Method Not Allowed";
-    case 406:
-        return "406 Not Acceptable";
-    case 407:
-        return "407 Proxy Authentication Required";
-    case 408:
-        return "408 Request Timeout";
-    case 409:
-        return "409 Conflict";
-    case 410:
-        return "410 Gone";
-    case 411:
-        return "411 Length Required";
-    case 412:
-        return "412 Precondition Failed";
-    case 413:
-        return "413 Request Entity Too Large";
-    case 414:
-        return "414 Request URI Too Long";
-    case 415:
-        return "415 Unsupported Media Type";
-    case 416:
-        return "416 Requested Range Not Satisfiable";
-    case 417:
-        return "417 Expectation Failed";
-    case 418:
-        return "418 I'm a teapot";
-    case 421:
-        return "421 Misdirected Request";
-    case 422:
-        return "422 Unprocessable Entity";
-    case 423:
-        return "423 Locked";
-    case 424:
-        return "424 Failed Dependency";
-    case 426:
-        return "426 Upgrade Required";
-    case 428:
-        return "428 Precondition Required";
-    case 429:
-        return "429 Too Many Requests";
-    case 431:
-        return "431 Request Header Fields Too Large";
-    case 500:
-        return "500 Internal Server Error";
-    case 501:
-        return "501 Method Not Implemented";
-    case 502:
-        return "502 Bad Gateway";
-    case 503:
-        return "503 Service Unavailable";
-    case 504:
-        return "504 Gateway Timeout";
-    case 505:
-        return "505 HTTP Version Not Supported";
-    case 506:
-        return "506 Variant Also Negotiates";
-    case 507:
-        return "507 Insufficient Storage";
-    case 508:
-        return "508 Loop Detected";
-    case 510:
-        return "510 Not Extended";
-    case 511:
-        return "511 Network Authentication Required";
-    case 200:
-    default:
-        return "200 OK";
-    }
-}
-
 void php_swoole_http_server_before_start(swServer *serv, zval *zobject)
 {
     swoole_http_buffer = swString_new(SW_HTTP_RESPONSE_INIT_SIZE);
     if (!swoole_http_buffer)
     {
-        swoole_php_fatal_error(E_ERROR, "[1] swString_new(%d) failed.", SW_HTTP_RESPONSE_INIT_SIZE);
+        swoole_php_fatal_error(E_ERROR, "[1] swString_new(%d) failed", SW_HTTP_RESPONSE_INIT_SIZE);
         return;
     }
 
     swoole_http_form_data_buffer = swString_new(SW_HTTP_RESPONSE_INIT_SIZE);
     if (!swoole_http_form_data_buffer)
     {
-        swoole_php_fatal_error(E_ERROR, "[2] swString_new(%d) failed.", SW_HTTP_RESPONSE_INIT_SIZE);
+        swoole_php_fatal_error(E_ERROR, "[2] swString_new(%d) failed", SW_HTTP_RESPONSE_INIT_SIZE);
         return;
     }
 
     //for is_uploaded_file and move_uploaded_file
     ALLOC_HASHTABLE(SG(rfc1867_uploaded_files));
     zend_hash_init(SG(rfc1867_uploaded_files), 8, NULL, NULL, 0);
+
+    if (!instanceof_function(Z_OBJCE_P(zobject), swoole_http_server_ce))
+    {
+        swoole_php_error(E_WARNING, "use %s class and open http related protocols may lead to some errors (inconsistent class type)", ZSTR_VAL(Z_OBJCE_P(zobject)->name));
+    }
 }
 
 static PHP_METHOD(swoole_http_request, rawContent)
@@ -1332,7 +1212,7 @@ static PHP_METHOD(swoole_http_request, rawContent)
 #endif
     else
     {
-        RETURN_FALSE;
+        RETURN_EMPTY_STRING();
     }
 }
 
@@ -1351,9 +1231,9 @@ static PHP_METHOD(swoole_http_request, getData)
 
 static PHP_METHOD(swoole_http_request, __destruct)
 {
-    SW_PREVENT_USER_DESTRUCT;
+    SW_PREVENT_USER_DESTRUCT();
 
-    zval *ztmpfiles = sw_zend_read_property(swoole_http_request_ce_ptr, getThis(), ZEND_STRL("tmpfiles"), 1);
+    zval *ztmpfiles = sw_zend_read_property(swoole_http_request_ce, getThis(), ZEND_STRL("tmpfiles"), 1);
     //upload files
     if (ztmpfiles && Z_TYPE_P(ztmpfiles) == IS_ARRAY)
     {
@@ -1398,7 +1278,7 @@ static PHP_METHOD(swoole_http_response, write)
 #ifdef SW_USE_HTTP2
     if (ctx->stream)
     {
-        swoole_php_error(E_WARNING, "Http2 client does not support HTTP-CHUNK.");
+        swoole_php_error(E_WARNING, "Http2 client does not support HTTP-CHUNK");
         RETURN_FALSE;
     }
 #endif
@@ -1427,7 +1307,7 @@ static PHP_METHOD(swoole_http_response, write)
 
     if (length == 0)
     {
-        swoole_php_error(E_WARNING, "data to send is empty.");
+        swoole_php_error(E_WARNING, "data to send is empty");
         RETURN_FALSE;
     }
     else
@@ -1473,14 +1353,9 @@ static PHP_METHOD(swoole_http_response, write)
 static http_context* http_get_context(zval *zobject, int check_end)
 {
     http_context *ctx = (http_context *) swoole_get_object(zobject);
-    if (!ctx)
+    if (!ctx || (check_end && ctx->end))
     {
-        swoole_php_fatal_error(E_WARNING, "Http request is finished.");
-        return NULL;
-    }
-    if (check_end && ctx->end)
-    {
-        swoole_php_fatal_error(E_WARNING, "Http request is finished.");
+        swoole_php_fatal_error(E_WARNING, "Http request is finished");
         return NULL;
     }
     return ctx;
@@ -1501,7 +1376,7 @@ static void http_build_header(http_context *ctx, zval *zobject, swString *respon
      */
     if (!ctx->response.reason)
     {
-        n = sw_snprintf(buf, l_buf, "HTTP/1.1 %s\r\n", http_status_message(ctx->response.status));
+        n = sw_snprintf(buf, l_buf, "HTTP/1.1 %s\r\n", swHttp_get_status_message(ctx->response.status));
     }
     else
     {
@@ -1512,7 +1387,7 @@ static void http_build_header(http_context *ctx, zval *zobject, swString *respon
     /**
      * http header
      */
-    zval *zheader = sw_zend_read_property(swoole_http_response_ce_ptr, ctx->response.zobject, ZEND_STRL("header"), 1);
+    zval *zheader = sw_zend_read_property(swoole_http_response_ce, ctx->response.zobject, ZEND_STRL("header"), 1);
     uint32_t header_flag = 0x0;
     if (ZVAL_IS_ARRAY(zheader))
     {
@@ -1619,7 +1494,7 @@ static void http_build_header(http_context *ctx, zval *zobject, swString *respon
     }
 
     //http cookies
-    zval *zcookie = sw_zend_read_property(swoole_http_response_ce_ptr, ctx->response.zobject, ZEND_STRL("cookie"), 1);
+    zval *zcookie = sw_zend_read_property(swoole_http_response_ce, ctx->response.zobject, ZEND_STRL("cookie"), 1);
     if (ZVAL_IS_ARRAY(zcookie))
     {
         zval *value;
@@ -1745,7 +1620,7 @@ int swoole_http_response_compress(swString *body, int method, int level)
             input_size, input_buffer, &encoded_size, encoded_buffer
         ))
         {
-            swWarn("BrotliEncoderCompress() failed.");
+            swWarn("BrotliEncoderCompress() failed");
             return SW_ERR;
         }
         else
@@ -1807,7 +1682,7 @@ int swoole_http_response_compress(swString *body, int method, int level)
     }
     else
     {
-        swWarn("deflateInit2() failed, Error: [%d].", retval);
+        swWarn("deflateInit2() failed, Error: [%d]", retval);
     }
     return SW_ERR;
 }
@@ -1821,23 +1696,24 @@ static PHP_METHOD(swoole_http_response, initHeader)
         RETURN_FALSE;
     }
     zval *zresponse_object = ctx->response.zobject;
-    zval *zheader = sw_zend_read_property(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("header"), 1);
+    zval *zheader = sw_zend_read_property(swoole_http_response_ce, zresponse_object, ZEND_STRL("header"), 1);
     if (!ZVAL_IS_ARRAY(zheader))
     {
         swoole_http_server_array_init(header, response);
     }
-
-    zval *zcookie = sw_zend_read_property(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("cookie"), 1);
+    zval *zcookie = sw_zend_read_property(swoole_http_response_ce, zresponse_object, ZEND_STRL("cookie"), 1);
     if (!ZVAL_IS_ARRAY(zcookie))
     {
         swoole_http_server_array_init(cookie, response);
     }
-
-    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("trailer"), 1);
+#ifdef SW_USE_HTTP2
+    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce, zresponse_object, ZEND_STRL("trailer"), 1);
     if (!ZVAL_IS_ARRAY(ztrailer))
     {
         swoole_http_server_array_init(trailer, response);
     }
+#endif
+    RETURN_TRUE;
 }
 
 static PHP_METHOD(swoole_http_response, end)
@@ -1871,7 +1747,7 @@ static PHP_METHOD(swoole_http_response, end)
 #ifdef SW_USE_HTTP2
     if (ctx->stream)
     {
-        swoole_http2_do_response(ctx, &http_body);
+        swoole_http2_server_do_response(ctx, &http_body);
         RETURN_TRUE;
     }
 #endif
@@ -1994,7 +1870,7 @@ static PHP_METHOD(swoole_http_response, sendfile)
     }
     if (filename_length <= 0)
     {
-        swoole_php_error(E_WARNING, "file name is empty.");
+        swoole_php_error(E_WARNING, "file name is empty");
         RETURN_FALSE;
     }
 
@@ -2010,29 +1886,29 @@ static PHP_METHOD(swoole_http_response, sendfile)
 
     if (ctx->chunk)
     {
-        swoole_php_fatal_error(E_ERROR, "can't use sendfile when Http-Chunk is enabled.");
+        swoole_php_fatal_error(E_ERROR, "can't use sendfile when Http-Chunk is enabled");
         RETURN_FALSE;
     }
 
     struct stat file_stat;
     if (stat(filename, &file_stat) < 0)
     {
-        swoole_php_sys_error(E_WARNING, "stat(%s) failed.", filename);
+        swoole_php_sys_error(E_WARNING, "stat(%s) failed", filename);
         RETURN_FALSE;
     }
     if (file_stat.st_size == 0)
     {
-        swoole_php_sys_error(E_WARNING, "can't send empty file[%s].", filename);
+        swoole_php_sys_error(E_WARNING, "can't send empty file[%s]", filename);
         RETURN_FALSE;
     }
     if (file_stat.st_size <= offset)
     {
-        swoole_php_error(E_WARNING, "parameter $offset[" ZEND_LONG_FMT "] exceeds the file size.", offset);
+        swoole_php_error(E_WARNING, "parameter $offset[" ZEND_LONG_FMT "] exceeds the file size", offset);
         RETURN_FALSE;
     }
     if (length > file_stat.st_size - offset)
     {
-        swoole_php_sys_error(E_WARNING, "parameter $length[" ZEND_LONG_FMT "] exceeds the file size.", length);
+        swoole_php_sys_error(E_WARNING, "parameter $length[" ZEND_LONG_FMT "] exceeds the file size", length);
         RETURN_FALSE;
     }
     if (length == 0)
@@ -2089,7 +1965,7 @@ static void swoole_http_response_cookie(INTERNAL_FUNCTION_PARAMETERS, bool url_e
         RETURN_FALSE;
     }
     zval *zresponse_object = ctx->response.zobject;
-    zval *zcookie = sw_zend_read_property(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("cookie"), 1);
+    zval *zcookie = sw_zend_read_property(swoole_http_response_ce, zresponse_object, ZEND_STRL("cookie"), 1);
     if (!ZVAL_IS_ARRAY(zcookie))
     {
         swoole_http_server_array_init(cookie, response);
@@ -2201,6 +2077,7 @@ static PHP_METHOD(swoole_http_response, status)
         ctx->response.reason = (char *) emalloc(SW_MEM_ALIGNED_SIZE(reason_len + 1));
         strncpy(ctx->response.reason, reason, reason_len);
     }
+    RETURN_TRUE;
 }
 
 static PHP_METHOD(swoole_http_response, header)
@@ -2223,19 +2100,19 @@ static PHP_METHOD(swoole_http_response, header)
     }
 
     zval *zresponse_object = ctx->response.zobject;
-    zval *zheader = sw_zend_read_property(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("header"), 1);
+    zval *zheader = sw_zend_read_property(swoole_http_response_ce, zresponse_object, ZEND_STRL("header"), 1);
     if (!ZVAL_IS_ARRAY(zheader))
     {
         swoole_http_server_array_init(header, response);
     }
     if (klen > SW_HTTP_HEADER_KEY_SIZE - 1)
     {
-        swoole_php_error(E_WARNING, "header key is too long.");
+        swoole_php_error(E_WARNING, "header key is too long");
         RETURN_FALSE;
     }
     if (vlen > SW_HTTP_HEADER_VALUE_SIZE)
     {
-        swoole_php_error(E_WARNING, "header value is too long.");
+        swoole_php_error(E_WARNING, "header value is too long");
         RETURN_FALSE;
     }
 
@@ -2260,7 +2137,7 @@ static PHP_METHOD(swoole_http_response, header)
     {
         add_assoc_stringl_ex(zheader, k, klen, v, vlen);
     }
-
+    RETURN_TRUE;
 }
 
 #ifdef SW_USE_HTTP2
@@ -2268,57 +2145,52 @@ static PHP_METHOD(swoole_http_response, trailer)
 {
     char *k, *v;
     size_t klen, vlen;
-    zend_bool ucwords = 1;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "ss|b", &k, &klen, &v, &vlen, &ucwords) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "ss|b", &k, &klen, &v, &vlen) == FAILURE)
     {
         RETURN_FALSE;
     }
 
     http_context *ctx = http_get_context(getThis(), 0);
-    if (!ctx)
+    if (!ctx || !ctx->stream)
     {
         RETURN_FALSE;
     }
 
     zval *zresponse_object = ctx->response.zobject;
-    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce_ptr, zresponse_object, ZEND_STRL("trailer"), 1);
+    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce, zresponse_object, ZEND_STRL("trailer"), 0);
     if (!ZVAL_IS_ARRAY(ztrailer))
     {
         swoole_http_server_array_init(trailer, response);
     }
     if (klen > SW_HTTP_HEADER_KEY_SIZE - 1)
     {
-        swoole_php_error(E_WARNING, "trailer key is too long.");
+        swoole_php_error(E_WARNING, "trailer key is too long");
         RETURN_FALSE;
     }
     if (vlen > SW_HTTP_HEADER_VALUE_SIZE)
     {
-        swoole_php_error(E_WARNING, "trailer value is too long.");
+        swoole_php_error(E_WARNING, "trailer value is too long");
         RETURN_FALSE;
     }
-
-    if (ucwords)
+    if (true)
     {
         char key_buf[SW_HTTP_HEADER_KEY_SIZE];
-        memcpy(key_buf, k, klen);
-        key_buf[klen] = '\0';
-#ifdef SW_USE_HTTP2
-        if (ctx->stream)
-        {
-            swoole_strtolower(key_buf, klen);
-        }
-        else
-#endif
-        {
-            http_header_key_format(key_buf, klen);
-        }
+        strncpy(key_buf, k, klen)[klen] = '\0';
+        swoole_strtolower(key_buf, klen);
         add_assoc_stringl_ex(ztrailer, key_buf, klen, v, vlen);
     }
-    else
+    RETURN_TRUE;
+}
+
+static PHP_METHOD(swoole_http_response, ping)
+{
+    http_context *ctx = http_get_context(getThis(), 0);
+    if (!ctx || !ctx->stream)
     {
-        add_assoc_stringl_ex(ztrailer, k, klen, v, vlen);
+        RETURN_FALSE;
     }
+    SW_CHECK_RETURN(swoole_http2_server_ping(ctx));
 }
 #endif
 
@@ -2344,18 +2216,18 @@ static PHP_METHOD(swoole_http_response, create)
     http_context *ctx = (http_context *) emalloc(sizeof(http_context));
     if (!ctx)
     {
-        swoole_error_log(SW_LOG_ERROR, SW_ERROR_MALLOC_FAIL, "emalloc(%ld) failed.", sizeof(http_context));
+        swoole_error_log(SW_LOG_ERROR, SW_ERROR_MALLOC_FAIL, "emalloc(%ld) failed", sizeof(http_context));
         RETURN_FALSE;
     }
     bzero(ctx, sizeof(http_context));
     ctx->fd = (int) fd;
 
-    object_init_ex(return_value, swoole_http_response_ce_ptr);
+    object_init_ex(return_value, swoole_http_response_ce);
     swoole_set_object(return_value, ctx);
     ctx->response.zobject = return_value;
     sw_copy_to_stack(ctx->response.zobject, ctx->response._zobject);
 
-    zend_update_property_long(swoole_http_response_ce_ptr, return_value, ZEND_STRL("fd"), ctx->fd);
+    zend_update_property_long(swoole_http_response_ce, return_value, ZEND_STRL("fd"), ctx->fd);
 }
 
 static PHP_METHOD(swoole_http_response, redirect)
@@ -2385,23 +2257,20 @@ static PHP_METHOD(swoole_http_response, redirect)
         ctx->response.status = 302;
     }
 
-    //header
     zval key;
     ZVAL_STRINGL(&key, "Location", 8);
-    zend_call_method_with_2_params(getThis(), NULL, NULL, "header", return_value, &key, url);
+    sw_zend_call_method_with_2_params(getThis(), NULL, NULL, "header", return_value, &key, url);
     zval_ptr_dtor(&key);
-    if (!ZVAL_IS_NULL(return_value))
+    if (!Z_BVAL_P(return_value))
     {
         return;
     }
-
-    //end
-    zend_call_method_with_0_params(getThis(), NULL, NULL, "end", return_value);
+    sw_zend_call_method_with_0_params(getThis(), NULL, NULL, "end", NULL);
 }
 
 static PHP_METHOD(swoole_http_response, __destruct)
 {
-    SW_PREVENT_USER_DESTRUCT;
+    SW_PREVENT_USER_DESTRUCT();
 
     http_context *context = (http_context *) swoole_get_object(getThis());
     if (context)
@@ -2417,15 +2286,7 @@ static PHP_METHOD(swoole_http_response, __destruct)
             {
                 context->response.status = 500;
             }
-
-            zval *zobject = getThis();
-            zval *retval = NULL;
-            sw_zend_call_method_with_0_params(&zobject, swoole_http_response_ce_ptr, NULL, "end", &retval);
-            if (retval)
-            {
-                zval_ptr_dtor(retval);
-            }
-
+            sw_zend_call_method_with_0_params(getThis(), swoole_http_response_ce, NULL, "end", NULL);
             context = (http_context *) swoole_get_object(getThis());
             if (context)
             {
