@@ -101,42 +101,28 @@ using namespace swoole;
 
 static std::unordered_map<int, http2_session*> http2_sessions;
 
-static sw_inline void http2_add_header(nghttp2_nv *headers, const char *k, int kl, const char *v, int vl)
+static ssize_t http2_build_trailer(http_context *ctx, uchar *buffer)
 {
-    headers->name = (uchar*) k;
-    headers->namelen = kl;
-    headers->value = (uchar*) v;
-    headers->valuelen = vl;
-}
+    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce, ctx->response.zobject, ZEND_STRL("trailer"), 0);
+    uint32_t size = ZVAL_IS_ARRAY(ztrailer) ? php_swoole_array_length(ztrailer) : 0;
 
-static int http_build_trailer(http_context *ctx, uchar *buffer)
-{
-    int ret;
-    size_t index = 0;
-    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce_ptr, ctx->response.zobject, ZEND_STRL("trailer"), 0);
-    uint32_t nv_size = ZVAL_IS_ARRAY(ztrailer) ? php_swoole_array_length(ztrailer) : 0;
-    std::vector<zend::string_ptr> zstr_list;
-
-    if (nv_size > 0)
+    if (size > 0)
     {
-        nghttp2_nv *nv = (nghttp2_nv *) ecalloc(sizeof(nghttp2_nv), nv_size);
+        http2::headers trailer(size);
         HashTable *ht = Z_ARRVAL_P(ztrailer);
+        zend_string *key = NULL;
         zval *value = NULL;
-        char *key = NULL;
-        uint32_t keylen = 0;
-        int type;
-        SW_HASHTABLE_FOREACH_START2(ht, key, keylen, type, value)
+
+        ZEND_HASH_FOREACH_STR_KEY_VAL(ht, key, value)
         {
-            if (!key || ZVAL_IS_NULL(value))
+            zend::string str_value(value);
+            if (!key || str_value.len())
             {
                 continue;
             }
-            zend_string *zstr = zval_get_string(value);
-            http2_add_header(&nv[index++], key, keylen, ZSTR_VAL(zstr), ZSTR_LEN(zstr));
-            zstr_list.emplace_back(zend::string_ptr(zstr));
+            trailer.add(ZSTR_VAL(key), ZSTR_LEN(key), str_value.val(), str_value.len());
         }
-        SW_HASHTABLE_FOREACH_END();
-        (void) type;
+        ZEND_HASH_FOREACH_END();
 
         ssize_t rv;
         size_t buflen;
@@ -145,36 +131,30 @@ static int http_build_trailer(http_context *ctx, uchar *buffer)
 
         if (!deflater)
         {
-            ret = nghttp2_hd_deflate_new(&deflater, SW_HTTP2_DEFAULT_HEADER_TABLE_SIZE);
+            int ret = nghttp2_hd_deflate_new(&deflater, SW_HTTP2_DEFAULT_HEADER_TABLE_SIZE);
             if (ret != 0)
             {
-                swoole_php_error(E_WARNING, "nghttp2_hd_deflate_init() failed with error: %s\n", nghttp2_strerror(ret));
-                return SW_ERR;
+                swWarn("nghttp2_hd_deflate_init() failed with error: %s", nghttp2_strerror(ret));
+                return -1;
             }
             client->deflater = deflater;
         }
 
-        buflen = nghttp2_hd_deflate_bound(deflater, nv, index);
+        buflen = nghttp2_hd_deflate_bound(deflater, trailer.get(), trailer.len());
         if (buflen > SW_HTTP2_DEFAULT_MAX_HEADER_LIST_SIZE)
         {
-            swoole_php_error(E_WARNING, "header cannot bigger than remote max_header_list_size %u.", SW_HTTP2_DEFAULT_MAX_HEADER_LIST_SIZE);
-            efree(nv);
-            return SW_ERR;
+            swoole_php_error(E_WARNING, "header cannot bigger than remote max_header_list_size %u", SW_HTTP2_DEFAULT_MAX_HEADER_LIST_SIZE);
+            return -1;
         }
-        rv = nghttp2_hd_deflate_hd(deflater, (uchar *) buffer, buflen, nv, index);
+        rv = nghttp2_hd_deflate_hd(deflater, (uchar *) buffer, buflen, trailer.get(), trailer.len());
         if (rv < 0)
         {
-            swoole_php_error(E_WARNING, "nghttp2_hd_deflate_hd() failed with error: %s\n", nghttp2_strerror((int ) rv));
-            efree(nv);
-            return SW_ERR;
+            swWarn("nghttp2_hd_deflate_hd() failed with error: %s", nghttp2_strerror((int ) rv));
+            return -1;
         }
-
-        efree(nv);
-
         return rv;
     }
-
-    return SW_OK;
+    return 0;
 }
 
 static sw_inline void http2_onRequest(http_context *ctx, int from_fd)
@@ -193,7 +173,7 @@ static sw_inline void http2_onRequest(http_context *ctx, int from_fd)
     {
         if (PHPCoroutine::create(fci_cache, 2, args) < 0)
         {
-            swoole_php_error(E_WARNING, "create Http2 onRequest coroutine error.");
+            swoole_php_error(E_WARNING, "create Http2 onRequest coroutine error");
             serv->factory.end(&serv->factory, fd);
         }
     }
@@ -202,7 +182,7 @@ static sw_inline void http2_onRequest(http_context *ctx, int from_fd)
         zval _retval, *retval = &_retval;
         if (sw_call_user_function_fast_ex(NULL, fci_cache, retval, 2, args) == FAILURE)
         {
-            swoole_php_error(E_WARNING, "Http2 onRequest handler error.");
+            swoole_php_error(E_WARNING, "Http2 onRequest handler error");
         }
         zval_ptr_dtor(retval);
     }
@@ -214,13 +194,12 @@ static sw_inline void http2_onRequest(http_context *ctx, int from_fd)
 static int http2_build_header(http_context *ctx, uchar *buffer, size_t body_length)
 {
     swServer *serv = SwooleG.serv;
+    zval *zheader = sw_zend_read_property(swoole_http_response_ce, ctx->response.zobject, ZEND_STRL("header"), 0);
+    zval *zcookie = sw_zend_read_property(swoole_http_response_ce, ctx->response.zobject, ZEND_STRL("cookie"), 0);
+    http2::headers headers(8 + php_swoole_array_length_safe(zheader) + php_swoole_array_length_safe(zcookie));
     char *date_str = NULL;
     char intbuf[2][16];
     int ret;
-    size_t index = 0;
-    zval *zheader = sw_zend_read_property(swoole_http_response_ce_ptr, ctx->response.zobject, ZEND_STRL("header"), 1);
-    nghttp2_nv *nv = (nghttp2_nv *) ecalloc(sizeof(nghttp2_nv), 8 + (ZVAL_IS_ARRAY(zheader) ? php_swoole_array_length(zheader) : 0));
-    std::vector<zend::string_ptr> zstr_list;
 
     assert(ctx->send_header == 0);
 
@@ -230,92 +209,92 @@ static int http2_build_header(http_context *ctx, uchar *buffer, size_t body_leng
         ctx->response.status = 200;
     }
     ret = swoole_itoa(intbuf[0], ctx->response.status);
-    http2_add_header(&nv[index++], ZEND_STRL(":status"), intbuf[0], ret);
+    headers.add(ZEND_STRL(":status"), intbuf[0], ret);
 
     // headers
     if (ZVAL_IS_ARRAY(zheader))
     {
         uint32_t header_flag = 0x0;
         HashTable *ht = Z_ARRVAL_P(zheader);
+        zend_string *key = NULL;
         zval *value = NULL;
-        char *key = NULL;
-        uint32_t keylen = 0;
-        int type;
 
-        SW_HASHTABLE_FOREACH_START2(ht, key, keylen, type, value)
+        ZEND_HASH_FOREACH_STR_KEY_VAL(ht, key, value)
         {
-            if (!key)
+            zend::string str_value(value);
+            char *c_key = ZSTR_VAL(key);
+            size_t c_keylen = ZSTR_LEN(key);
+            if (UNEXPECTED(!c_key || str_value.len() == 0))
             {
                 continue;
             }
-            if (strncmp(key, "server", keylen) == 0)
+            if (strncmp("server", c_key, c_keylen) == 0)
             {
                 header_flag |= HTTP_HEADER_SERVER;
             }
-            else if (strncmp(key, "content-length", keylen) == 0)
+            else if (strncmp("content-length", c_key, c_keylen) == 0)
             {
                 continue; // ignore
             }
-            else if (strncmp(key, "date", keylen) == 0)
+            else if (strncmp("date", c_key, c_keylen) == 0)
             {
                 header_flag |= HTTP_HEADER_DATE;
             }
-            else if (strncmp(key, "content-type", keylen) == 0)
+            else if (strncmp("content-type", c_key, c_keylen) == 0)
             {
                 header_flag |= HTTP_HEADER_CONTENT_TYPE;
             }
-            if (!ZVAL_IS_NULL(value))
-            {
-                zend_string *zstr = zval_get_string(value);
-                http2_add_header(&nv[index++], key, keylen, ZSTR_VAL(zstr), ZSTR_LEN(zstr));
-                zstr_list.emplace_back(zend::string_ptr(zstr));
-            }
+            headers.add(c_key, c_keylen, str_value.val(), str_value.len());
         }
-        SW_HASHTABLE_FOREACH_END();
-        (void)type;
+        ZEND_HASH_FOREACH_END();
 
         if (!(header_flag & HTTP_HEADER_SERVER))
         {
-            http2_add_header(&nv[index++], ZEND_STRL("server"), ZEND_STRL(SW_HTTP_SERVER_SOFTWARE));
+            headers.add(ZEND_STRL("server"), ZEND_STRL(SW_HTTP_SERVER_SOFTWARE));
         }
         if (!(header_flag & HTTP_HEADER_DATE))
         {
             date_str = sw_php_format_date((char *)ZEND_STRL(SW_HTTP_DATE_FORMAT), serv->gs->now, 0);
-            http2_add_header(&nv[index++], ZEND_STRL("date"), date_str, strlen(date_str));
+            headers.add(ZEND_STRL("date"), date_str, strlen(date_str));
         }
         if (!(header_flag & HTTP_HEADER_CONTENT_TYPE))
         {
-            http2_add_header(&nv[index++], ZEND_STRL("content-type"), ZEND_STRL("text/html"));
+            headers.add(ZEND_STRL("content-type"), ZEND_STRL("text/html"));
         }
     }
     else
     {
-        http2_add_header(&nv[index++], ZEND_STRL("server"), ZEND_STRL(SW_HTTP_SERVER_SOFTWARE));
-        http2_add_header(&nv[index++], ZEND_STRL("content-type"), ZEND_STRL("text/html"));
+        headers.add(ZEND_STRL("server"), ZEND_STRL(SW_HTTP_SERVER_SOFTWARE));
+        headers.add(ZEND_STRL("content-type"), ZEND_STRL("text/html"));
         date_str = sw_php_format_date((char *)ZEND_STRL(SW_HTTP_DATE_FORMAT), serv->gs->now, 0);
-        http2_add_header(&nv[index++], ZEND_STRL("date"), date_str, strlen(date_str));
+        headers.add(ZEND_STRL("date"), date_str, strlen(date_str));
+    }
+    if (date_str)
+    {
+        efree(date_str);
     }
 
     // cookies
-    zval *zcookie = sw_zend_read_property(swoole_http_response_ce_ptr, ctx->response.zobject, ZEND_STRL("cookie"), 1);
     if (ZVAL_IS_ARRAY(zcookie))
     {
-        zval *value;
-        SW_HASHTABLE_FOREACH_START(Z_ARRVAL_P(zcookie), value)
+        zval *zvalue;
+        SW_HASHTABLE_FOREACH_START(Z_ARRVAL_P(zcookie), zvalue)
         {
-            if (Z_TYPE_P(value) != IS_STRING)
+            if (Z_TYPE_P(zvalue) != IS_STRING)
             {
                 continue;
             }
-            http2_add_header(&nv[index++], ZEND_STRL("set-cookie"), Z_STRVAL_P(value), Z_STRLEN_P(value));
+            headers.add(ZEND_STRL("set-cookie"), Z_STRVAL_P(zvalue), Z_STRLEN_P(zvalue));
         }
         SW_HASHTABLE_FOREACH_END();
     }
+
+    // content encoding
 #ifdef SW_HAVE_ZLIB
     if (ctx->enable_compression)
     {
         const char *content_encoding = swoole_http_get_content_encoding(ctx);
-        http2_add_header(&nv[index++], ZEND_STRL("content-encoding"), (char *) content_encoding, strlen(content_encoding));
+        headers.add(ZEND_STRL("content-encoding"), (char *) content_encoding, strlen(content_encoding));
     }
 #endif
 
@@ -327,12 +306,10 @@ static int http2_build_header(http_context *ctx, uchar *buffer, size_t body_leng
     }
 #endif
     ret = swoole_itoa(intbuf[1], body_length);
-    http2_add_header(&nv[index++], ZEND_STRL("content-length"), intbuf[1], ret);
+    headers.add(ZEND_STRL("content-length"), intbuf[1], ret);
 
     ctx->send_header = 1;
 
-    ssize_t rv = SW_ERR;
-    size_t buflen;
     http2_session *client = http2_sessions[ctx->fd];
     nghttp2_hd_deflater *deflater = client->deflater;
     if (!deflater)
@@ -340,36 +317,37 @@ static int http2_build_header(http_context *ctx, uchar *buffer, size_t body_leng
         ret = nghttp2_hd_deflate_new(&deflater, SW_HTTP2_DEFAULT_HEADER_TABLE_SIZE);
         if (ret != 0)
         {
-            swoole_php_error(E_WARNING, "nghttp2_hd_deflate_init() failed with error: %s\n", nghttp2_strerror(ret));
-            goto _error;
+            swWarn("nghttp2_hd_deflate_init() failed with error: %s", nghttp2_strerror(ret));
+            return -1;
         }
         client->deflater = deflater;
     }
 
-    buflen = nghttp2_hd_deflate_bound(deflater, nv, index);
+    size_t buflen = nghttp2_hd_deflate_bound(deflater, headers.get(), headers.len());
     if (buflen > SW_HTTP2_DEFAULT_MAX_HEADER_LIST_SIZE)
     {
-        swoole_php_error(E_WARNING, "header cannot bigger than remote max_header_list_size %u.", SW_HTTP2_DEFAULT_MAX_HEADER_LIST_SIZE);
-        goto _error;
+        swoole_php_error(E_WARNING, "header cannot bigger than remote max_header_list_size %u", SW_HTTP2_DEFAULT_MAX_HEADER_LIST_SIZE);
+        return -1;
     }
-    rv = nghttp2_hd_deflate_hd(deflater, (uchar *) buffer, buflen, nv, index);
+    ssize_t rv = nghttp2_hd_deflate_hd(deflater, (uchar *) buffer, buflen, headers.get(), headers.len());
     if (rv < 0)
     {
-        swoole_php_error(E_WARNING, "nghttp2_hd_deflate_hd() failed with error: %s\n", nghttp2_strerror((int ) rv));
-        goto _error;
+        swWarn("nghttp2_hd_deflate_hd() failed with error: %s", nghttp2_strerror((int ) rv));
+        return -1;
     }
 
-    _error:
-    if (date_str)
-    {
-        efree(date_str);
-    }
-    efree(nv);
-
     return rv;
 }
 
-int swoole_http2_do_response(http_context *ctx, swString *body)
+int swoole_http2_server_ping(http_context *ctx)
+{
+    swServer *serv = SwooleG.serv;
+    char frame[SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_FRAME_PING_PAYLOAD_SIZE];
+    swHttp2_set_frame_header(frame, SW_HTTP2_TYPE_PING, SW_HTTP2_FRAME_PING_PAYLOAD_SIZE, SW_HTTP2_FLAG_NONE, 0);
+    return serv->send(serv, ctx->fd, frame, SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_FRAME_PING_PAYLOAD_SIZE);
+}
+
+int swoole_http2_server_do_response(http_context *ctx, swString *body)
 {
     http2_session *client = http2_sessions[ctx->fd];
     http2_stream *stream = (http2_stream *) ctx->stream;
@@ -408,7 +386,7 @@ int swoole_http2_do_response(http_context *ctx, swString *body)
      +---------------------------------------------------------------+
      */
     char frame_header[SW_HTTP2_FRAME_HEADER_SIZE];
-    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce_ptr, ctx->response.zobject, ZEND_STRL("trailer"), 1);
+    zval *ztrailer = sw_zend_read_property(swoole_http_response_ce, ctx->response.zobject, ZEND_STRL("trailer"), 1);
     if (!ZVAL_IS_ARRAY(ztrailer))
     {
         ztrailer = NULL;
@@ -497,21 +475,23 @@ int swoole_http2_do_response(http_context *ctx, swString *body)
     {
         swString_clear(swoole_http_buffer);
         memset(header_buffer, 0, sizeof(header_buffer));
-        ret = http_build_trailer(ctx, (uchar *) header_buffer);
-        swHttp2_set_frame_header(frame_header, SW_HTTP2_TYPE_HEADERS, ret, SW_HTTP2_FLAG_END_HEADERS | SW_HTTP2_FLAG_END_STREAM, stream->stream_id);
-        swString_append_ptr(swoole_http_buffer, frame_header, SW_HTTP2_FRAME_HEADER_SIZE);
-        swString_append_ptr(swoole_http_buffer, header_buffer, ret);
-
-        if (serv->send(serv, ctx->fd, swoole_http_buffer->str, swoole_http_buffer->length) < 0)
+        ret = http2_build_trailer(ctx, (uchar *) header_buffer);
+        if (ret > 0)
         {
-            return SW_ERR;
+            swHttp2_set_frame_header(frame_header, SW_HTTP2_TYPE_HEADERS, ret, SW_HTTP2_FLAG_END_HEADERS | SW_HTTP2_FLAG_END_STREAM, stream->stream_id);
+            swString_append_ptr(swoole_http_buffer, frame_header, SW_HTTP2_FRAME_HEADER_SIZE);
+            swString_append_ptr(swoole_http_buffer, header_buffer, ret);
+            if (serv->send(serv, ctx->fd, swoole_http_buffer->str, swoole_http_buffer->length) < 0)
+            {
+                return SW_ERR;
+            }
         }
     }
 
     _end:
     if (body->length > 0)
     {
-        client->send_window -= body->length;    // TODO:flow control?
+        client->send_window -= body->length;    // TODO: flow control?
     }
 
     client->streams.erase(stream->stream_id);
@@ -529,7 +509,7 @@ static int http2_parse_header(http2_session *client, http_context *ctx, int flag
         int ret = nghttp2_hd_inflate_new(&inflater);
         if (ret != 0)
         {
-            swoole_php_error(E_WARNING, "nghttp2_hd_inflate_init() failed, Error: %s[%d].", nghttp2_strerror(ret), ret);
+            swWarn("nghttp2_hd_inflate_init() failed, Error: %s[%d]", nghttp2_strerror(ret), ret);
             return SW_ERR;
         }
         client->inflater = inflater;
@@ -556,8 +536,8 @@ static int http2_parse_header(http2_session *client, http_context *ctx, int flag
         rv = nghttp2_hd_inflate_hd(inflater, &nv, &inflate_flags, (uchar *) in, inlen, 1);
         if (rv < 0)
         {
-            swoole_php_error(E_WARNING, "inflate failed, Error: %s[%zd].", nghttp2_strerror(rv), rv);
-            return -1;
+            swWarn("inflate failed, Error: %s[%zd]", nghttp2_strerror(rv), rv);
+            return SW_ERR;
         }
 
         proclen = (size_t) rv;
@@ -590,8 +570,7 @@ static int http2_parse_header(http2_session *client, http_context *ctx, int flag
                         add_assoc_stringl_ex(zserver, ZEND_STRL("query_string"), v_str, v_len);
                         zstr_path = zend_string_init(pathbuf, k_len, 0);
 
-                        zval *zget;
-                        zval *zrequest_object = ctx->request.zobject;
+                        zval *zget, *zrequest_object = ctx->request.zobject;
                         swoole_http_server_array_init(get, request);
 
                         //no need free, will free by treat_data
@@ -604,7 +583,9 @@ static int http2_parse_header(http2_session *client, http_context *ctx, int flag
                         zstr_path = zend_string_init((char *) nv.value, nv.valuelen, 0);
                     }
                     add_assoc_str_ex(zserver, ZEND_STRL("request_uri"), zstr_path);
-                    GC_ADDREF(zstr_path);
+                    // path_info should be decoded
+                    zstr_path = zend_string_dup(zstr_path, 0);
+                    ZSTR_LEN(zstr_path) = php_url_decode(ZSTR_VAL(zstr_path), ZSTR_LEN(zstr_path));
                     add_assoc_str_ex(zserver, ZEND_STRL("path_info"), zstr_path);
                 }
                 else if (strncasecmp((char *) nv.name + 1, "authority", nv.namelen -1) == 0)
@@ -625,8 +606,8 @@ static int http2_parse_header(http2_session *client, http_context *ctx, int flag
                         int boundary_len = nv.valuelen - strlen("multipart/form-data; boundary=");
                         if (boundary_len <= 0)
                         {
-                            swWarn("invalid multipart/form-data body fd:%d.", ctx->fd);
-                            return 0;
+                            swWarn("invalid multipart/form-data body fd:%d", ctx->fd);
+                            return SW_ERR;
                         }
                         swoole_http_parse_form_data(ctx, (char*) nv.value + nv.valuelen - boundary_len, boundary_len);
                         ctx->parser.data = ctx;
@@ -640,14 +621,7 @@ static int http2_parse_header(http2_session *client, http_context *ctx, int flag
                     {
                         swoole_http_server_array_init(cookie, request);
                     }
-
-                    char keybuf[SW_HTTP_COOKIE_KEYLEN];
-                    char *v_str = strchr((char *) nv.value, '=') + 1;
-                    int k_len = v_str - (char *) nv.value - 1;
-                    int v_len = nv.valuelen - k_len - 1;
-                    memcpy(keybuf, nv.value, k_len);
-                    keybuf[k_len] = 0;
-                    add_assoc_stringl_ex(zcookie, keybuf, k_len, v_str, v_len);
+                    swoole_http_parse_cookie(zcookie, (char *) nv.value, nv.valuelen);
                     continue;
                 }
 #ifdef SW_HAVE_ZLIB
@@ -688,7 +662,7 @@ static sw_inline void http2_server_send_window_update(int fd, int stream_id, uin
 /**
  * Http2
  */
-int swoole_http2_onFrame(swConnection *conn, swEventData *req)
+int swoole_http2_server_onFrame(swConnection *conn, swEventData *req)
 {
     swServer *serv = SwooleG.serv;
     int fd = req->info.fd;
@@ -735,27 +709,27 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
             switch (id)
             {
             case SW_HTTP2_SETTING_HEADER_TABLE_SIZE:
-                swTraceLog(SW_TRACE_HTTP2, "setting: header_compression_table_max=%u.", value);
+                swTraceLog(SW_TRACE_HTTP2, "setting: header_compression_table_max=%u", value);
                 break;
             case SW_HTTP2_SETTINGS_MAX_CONCURRENT_STREAMS:
                 client->max_concurrent_streams = value;
-                swTraceLog(SW_TRACE_HTTP2, "setting: max_concurrent_streams=%u.", value);
+                swTraceLog(SW_TRACE_HTTP2, "setting: max_concurrent_streams=%u", value);
                 break;
             case SW_HTTP2_SETTINGS_INIT_WINDOW_SIZE:
                 client->send_window = value;
-                swTraceLog(SW_TRACE_HTTP2, "setting: init_send_window=%u.", value);
+                swTraceLog(SW_TRACE_HTTP2, "setting: init_send_window=%u", value);
                 break;
             case SW_HTTP2_SETTINGS_MAX_FRAME_SIZE:
                 client->max_frame_size = value;
-                swTraceLog(SW_TRACE_HTTP2, "setting: max_frame_size=%u.", value);
+                swTraceLog(SW_TRACE_HTTP2, "setting: max_frame_size=%u", value);
                 break;
             case SW_HTTP2_SETTINGS_MAX_HEADER_LIST_SIZE:
                 // client->max_header_list_size = value; // useless now
-                swTraceLog(SW_TRACE_HTTP2, "setting: max_header_list_size=%u.", value);
+                swTraceLog(SW_TRACE_HTTP2, "setting: max_header_list_size=%u", value);
                 break;
             default:
                 // disable warning and ignore it because some websites are not following http2 protocol totally
-                // swWarn("unknown option[%d]: %d.", id, value);
+                // swWarn("unknown option[%d]: %d", id, value);
                 break;
             }
             buf += sizeof(id) + sizeof(value);
@@ -773,7 +747,7 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
             if (unlikely(!stream->ctx))
             {
                 zval_ptr_dtor(&zdata);
-                swoole_error_log(SW_LOG_WARNING, SW_ERROR_HTTP2_STREAM_NO_HEADER, "http2 create stream#%d context error.", stream_id);
+                swoole_error_log(SW_LOG_WARNING, SW_ERROR_HTTP2_STREAM_NO_HEADER, "http2 create stream#%d context error", stream_id);
                 return SW_ERR;
             }
             client->streams[stream_id] = stream;
@@ -797,7 +771,10 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
             ctx = stream->ctx;
         }
 
-        http2_parse_header(client, ctx, flags, buf, length);
+        if (http2_parse_header(client, ctx, flags, buf, length) < 0)
+        {
+            return SW_ERR;
+        }
 
         if (flags & SW_HTTP2_FLAG_END_STREAM)
         {
@@ -816,7 +793,7 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
         if (stream_iterator == client->streams.end())
         {
             zval_ptr_dtor(&zdata);
-            swoole_error_log(SW_LOG_WARNING, SW_ERROR_HTTP2_STREAM_NOT_FOUND, "http2 stream#%d not found.", stream_id);
+            swoole_error_log(SW_LOG_WARNING, SW_ERROR_HTTP2_STREAM_NOT_FOUND, "http2 stream#%d not found", stream_id);
             return SW_ERR;
         }
         stream = stream_iterator->second;
@@ -865,7 +842,7 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
                 size_t n = multipart_parser_execute(multipart_parser, buffer->str, buffer->length);
                 if (n != (size_t) length)
                 {
-                    swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_INVALID_REQUEST, "parse multipart body failed, n=%zu.", n);
+                    swoole_error_log(SW_LOG_WARNING, SW_ERROR_SERVER_INVALID_REQUEST, "parse multipart body failed, n=%zu", n);
                 }
             }
             http2_onRequest(ctx, from_fd);
@@ -875,10 +852,13 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
     case SW_HTTP2_TYPE_PING:
     {
         swHttp2FrameTraceLog(recv, "ping");
-        char ping_frame[SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_FRAME_PING_PAYLOAD_SIZE];
-        swHttp2_set_frame_header(ping_frame, SW_HTTP2_TYPE_PING, SW_HTTP2_FRAME_PING_PAYLOAD_SIZE, SW_HTTP2_FLAG_ACK, stream_id);
-        memcpy(ping_frame + SW_HTTP2_FRAME_HEADER_SIZE, buf, SW_HTTP2_FRAME_PING_PAYLOAD_SIZE);
-        serv->send(serv, fd, ping_frame, SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_FRAME_PING_PAYLOAD_SIZE);
+        if (!(flags & SW_HTTP2_FLAG_ACK))
+        {
+            char ping_frame[SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_FRAME_PING_PAYLOAD_SIZE];
+            swHttp2_set_frame_header(ping_frame, SW_HTTP2_TYPE_PING, SW_HTTP2_FRAME_PING_PAYLOAD_SIZE, SW_HTTP2_FLAG_ACK, stream_id);
+            memcpy(ping_frame + SW_HTTP2_FRAME_HEADER_SIZE, buf, SW_HTTP2_FRAME_PING_PAYLOAD_SIZE);
+            serv->send(serv, fd, ping_frame, SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_FRAME_PING_PAYLOAD_SIZE);
+        }
         break;
     }
     case SW_HTTP2_TYPE_WINDOW_UPDATE:
@@ -933,7 +913,7 @@ int swoole_http2_onFrame(swConnection *conn, swEventData *req)
     return SW_OK;
 }
 
-void swoole_http2_free(swConnection *conn)
+void swoole_http2_server_session_free(swConnection *conn)
 {
     auto session_iterator = http2_sessions.find(conn->session_id);
     if (session_iterator == http2_sessions.end())
