@@ -18,12 +18,10 @@
 
 #include "include/table.h"
 
-static zend_class_entry swoole_table_ce;
-static zend_class_entry *swoole_table_ce_ptr;
+static zend_class_entry *swoole_table_ce;
 static zend_object_handlers swoole_table_handlers;
 
-static zend_class_entry swoole_table_row_ce;
-static zend_class_entry *swoole_table_row_ce_ptr;
+static zend_class_entry *swoole_table_row_ce;
 static zend_object_handlers swoole_table_row_handlers;
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_void, 0, 0, 0)
@@ -254,27 +252,27 @@ static inline void php_swoole_table_get_field_value(swTable *table, swTableRow *
 
 void swoole_table_init(int module_number)
 {
-    SWOOLE_INIT_CLASS_ENTRY(swoole_table, "Swoole\\Table", "swoole_table", NULL, swoole_table_methods);
-    SWOOLE_SET_CLASS_SERIALIZABLE(swoole_table, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SWOOLE_SET_CLASS_CLONEABLE(swoole_table, zend_class_clone_deny);
-    SWOOLE_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_table, zend_class_unset_property_deny);
-    zend_class_implements(swoole_table_ce_ptr, 2, zend_ce_iterator, zend_ce_arrayaccess);
+    SW_INIT_CLASS_ENTRY(swoole_table, "Swoole\\Table", "swoole_table", NULL, swoole_table_methods);
+    SW_SET_CLASS_SERIALIZABLE(swoole_table, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_CLONEABLE(swoole_table, zend_class_clone_deny);
+    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_table, zend_class_unset_property_deny);
+    zend_class_implements(swoole_table_ce, 2, zend_ce_iterator, zend_ce_arrayaccess);
 #ifdef SW_HAVE_COUNTABLE
-    zend_class_implements(swoole_table_ce_ptr, 1, zend_ce_countable);
+    zend_class_implements(swoole_table_ce, 1, zend_ce_countable);
 #endif
 
-    zend_declare_class_constant_long(swoole_table_ce_ptr, ZEND_STRL("TYPE_INT"), SW_TABLE_INT);
-    zend_declare_class_constant_long(swoole_table_ce_ptr, ZEND_STRL("TYPE_STRING"), SW_TABLE_STRING);
-    zend_declare_class_constant_long(swoole_table_ce_ptr, ZEND_STRL("TYPE_FLOAT"), SW_TABLE_FLOAT);
+    zend_declare_class_constant_long(swoole_table_ce, ZEND_STRL("TYPE_INT"), SW_TABLE_INT);
+    zend_declare_class_constant_long(swoole_table_ce, ZEND_STRL("TYPE_STRING"), SW_TABLE_STRING);
+    zend_declare_class_constant_long(swoole_table_ce, ZEND_STRL("TYPE_FLOAT"), SW_TABLE_FLOAT);
 
-    SWOOLE_INIT_CLASS_ENTRY(swoole_table_row, "Swoole\\Table\\Row", "swoole_table_row", NULL, swoole_table_row_methods);
-    SWOOLE_SET_CLASS_SERIALIZABLE(swoole_table_row, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SWOOLE_SET_CLASS_CLONEABLE(swoole_table_row, zend_class_clone_deny);
-    SWOOLE_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_table_row, zend_class_unset_property_deny);
-    zend_class_implements(swoole_table_row_ce_ptr, 1, zend_ce_arrayaccess);
+    SW_INIT_CLASS_ENTRY(swoole_table_row, "Swoole\\Table\\Row", "swoole_table_row", NULL, swoole_table_row_methods);
+    SW_SET_CLASS_SERIALIZABLE(swoole_table_row, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_CLONEABLE(swoole_table_row, zend_class_clone_deny);
+    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_table_row, zend_class_unset_property_deny);
+    zend_class_implements(swoole_table_row_ce, 1, zend_ce_arrayaccess);
 
-    zend_declare_property_null(swoole_table_row_ce_ptr, ZEND_STRL("key"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_table_row_ce_ptr, ZEND_STRL("value"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_table_row_ce, ZEND_STRL("key"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_table_row_ce, ZEND_STRL("value"), ZEND_ACC_PUBLIC);
 }
 
 void swoole_table_column_free(swTableColumn *col)
@@ -296,7 +294,7 @@ PHP_METHOD(swoole_table, __construct)
     swTable *table = swTable_new(table_size, conflict_proportion);
     if (table == NULL)
     {
-        zend_throw_exception(swoole_exception_ce_ptr, "global memory allocation failure.", SW_ERROR_MALLOC_FAIL);
+        zend_throw_exception(swoole_exception_ce, "global memory allocation failure", SW_ERROR_MALLOC_FAIL);
         RETURN_FALSE;
     }
     swoole_set_object(getThis(), table);
@@ -313,20 +311,24 @@ PHP_METHOD(swoole_table, column)
     {
         RETURN_FALSE;
     }
-    if (type == SW_TABLE_STRING && size < 1)
+    if (type == SW_TABLE_STRING)
     {
-        swoole_php_fatal_error(E_WARNING, "the length of string type values has to be more than zero.");
-        RETURN_FALSE;
+        if (size < 1)
+        {
+            swoole_php_fatal_error(E_WARNING, "the length of string type values has to be more than zero");
+            RETURN_FALSE;
+        }
+        size = SW_MEM_ALIGNED_SIZE(size);
     }
     //default int32
-    if (type == SW_TABLE_INT && size < 1)
+    if (type == SW_TABLE_INT && size < 4)
     {
         size = 4;
     }
     swTable *table = swoole_get_object(getThis());
     if (table->memory)
     {
-        swoole_php_fatal_error(E_WARNING, "can't add column after the creation of swoole table.");
+        swoole_php_fatal_error(E_WARNING, "can't add column after the creation of swoole table");
         RETURN_FALSE;
     }
     swTableColumn_add(table, name, len, type, size);
@@ -338,16 +340,16 @@ static PHP_METHOD(swoole_table, create)
     swTable *table = swoole_get_object(getThis());
     if (table->memory)
     {
-        swoole_php_fatal_error(E_WARNING, "the swoole table has been created already.");
+        swoole_php_fatal_error(E_WARNING, "the swoole table has been created already");
         RETURN_FALSE;
     }
     if (swTable_create(table) < 0)
     {
-        swoole_php_fatal_error(E_ERROR, "unable to allocate memory.");
+        swoole_php_fatal_error(E_ERROR, "unable to allocate memory");
         RETURN_FALSE;
     }
-    zend_update_property_long(swoole_buffer_ce_ptr, getThis(), ZEND_STRL("size"), table->size);
-    zend_update_property_long(swoole_buffer_ce_ptr, getThis(), ZEND_STRL("memorySize"), table->memory_size);
+    zend_update_property_long(swoole_buffer_ce, getThis(), ZEND_STRL("size"), table->size);
+    zend_update_property_long(swoole_buffer_ce, getThis(), ZEND_STRL("memorySize"), table->memory_size);
     RETURN_TRUE;
 }
 
@@ -356,7 +358,7 @@ static PHP_METHOD(swoole_table, destroy)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -378,7 +380,7 @@ static PHP_METHOD(swoole_table, set)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -387,7 +389,7 @@ static PHP_METHOD(swoole_table, set)
     if (!row)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_error(E_WARNING, "unable to allocate memory.");
+        swoole_php_error(E_WARNING, "unable to allocate memory");
         RETURN_FALSE;
     }
 
@@ -450,7 +452,7 @@ static PHP_METHOD(swoole_table, incr)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -458,7 +460,7 @@ static PHP_METHOD(swoole_table, incr)
     if (!row)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "unable to allocate memory.");
+        swoole_php_fatal_error(E_WARNING, "unable to allocate memory");
         RETURN_FALSE;
     }
 
@@ -467,13 +469,13 @@ static PHP_METHOD(swoole_table, incr)
     if (column == NULL)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "column[%s] does not exist.", col);
+        swoole_php_fatal_error(E_WARNING, "column[%s] does not exist", col);
         RETURN_FALSE;
     }
     else if (column->type == SW_TABLE_STRING)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "can't execute 'incr' on a string type column.");
+        swoole_php_fatal_error(E_WARNING, "can't execute 'incr' on a string type column");
         RETURN_FALSE;
     }
     else if (column->type == SW_TABLE_FLOAT)
@@ -526,7 +528,7 @@ static PHP_METHOD(swoole_table, decr)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -534,7 +536,7 @@ static PHP_METHOD(swoole_table, decr)
     if (!row)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "unable to allocate memory.");
+        swoole_php_fatal_error(E_WARNING, "unable to allocate memory");
         RETURN_FALSE;
     }
 
@@ -543,13 +545,13 @@ static PHP_METHOD(swoole_table, decr)
     if (column == NULL)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "column[%s] does not exist.", col);
+        swoole_php_fatal_error(E_WARNING, "column[%s] does not exist", col);
         RETURN_FALSE;
     }
     else if (column->type == SW_TABLE_STRING)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "can't execute 'decr' on a string type column.");
+        swoole_php_fatal_error(E_WARNING, "can't execute 'decr' on a string type column");
         RETURN_FALSE;
     }
     else if (column->type == SW_TABLE_FLOAT)
@@ -601,7 +603,7 @@ static PHP_METHOD(swoole_table, get)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -637,7 +639,7 @@ static PHP_METHOD(swoole_table, offsetGet)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "Must create table first.");
+        swoole_php_fatal_error(E_ERROR, "Must create table first");
         RETURN_FALSE;
     }
 
@@ -654,9 +656,9 @@ static PHP_METHOD(swoole_table, offsetGet)
     }
     swTableRow_unlock(_rowlock);
 
-    object_init_ex(return_value, swoole_table_row_ce_ptr);
-    zend_update_property(swoole_table_row_ce_ptr, return_value, ZEND_STRL("value"), &value);
-    zend_update_property_stringl(swoole_table_row_ce_ptr, return_value, ZEND_STRL("key"), key, keylen);
+    object_init_ex(return_value, swoole_table_row_ce);
+    zend_update_property(swoole_table_row_ce, return_value, ZEND_STRL("value"), &value);
+    zend_update_property_stringl(swoole_table_row_ce, return_value, ZEND_STRL("key"), key, keylen);
     zval_ptr_dtor(&value);
     swoole_set_object(return_value, table);
 }
@@ -674,7 +676,7 @@ static PHP_METHOD(swoole_table, exists)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -709,7 +711,7 @@ static PHP_METHOD(swoole_table, del)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
     SW_CHECK_RETURN(swTableRow_del(table, key, keylen));
@@ -735,7 +737,7 @@ static PHP_METHOD(swoole_table, count)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
 
@@ -767,7 +769,7 @@ static PHP_METHOD(swoole_table, rewind)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
     swTable_iterator_rewind(table);
@@ -779,7 +781,7 @@ static PHP_METHOD(swoole_table, current)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
     swTableRow *row = swTable_iterator_current(table);
@@ -793,7 +795,7 @@ static PHP_METHOD(swoole_table, key)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
     swTableRow *row = swTable_iterator_current(table);
@@ -807,7 +809,7 @@ static PHP_METHOD(swoole_table, next)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
     swTable_iterator_forward(table);
@@ -818,7 +820,7 @@ static PHP_METHOD(swoole_table, valid)
     swTable *table = swoole_get_object(getThis());
     if (!table->memory)
     {
-        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist.");
+        swoole_php_fatal_error(E_ERROR, "the swoole table does not exist");
         RETURN_FALSE;
     }
     swTableRow *row = swTable_iterator_current(table);
@@ -835,7 +837,7 @@ static PHP_METHOD(swoole_table_row, offsetExists)
         RETURN_FALSE;
     }
 
-    zval *zprop_value = sw_zend_read_property(swoole_table_row_ce_ptr, getThis(), ZEND_STRL("value"), 0);
+    zval *zprop_value = sw_zend_read_property(swoole_table_row_ce, getThis(), ZEND_STRL("value"), 0);
     RETURN_BOOL(zend_hash_str_exists(Z_ARRVAL_P(zprop_value), key, keylen));
 }
 
@@ -849,7 +851,7 @@ static PHP_METHOD(swoole_table_row, offsetGet)
         RETURN_FALSE;
     }
 
-    zval *zprop_value = sw_zend_read_property(swoole_table_row_ce_ptr, getThis(), ZEND_STRL("value"), 0);
+    zval *zprop_value = sw_zend_read_property(swoole_table_row_ce, getThis(), ZEND_STRL("value"), 0);
     zval *retval = NULL;
     if (!(retval = zend_hash_str_find(Z_ARRVAL_P(zprop_value), key, keylen)))
     {
@@ -872,18 +874,18 @@ static PHP_METHOD(swoole_table_row, offsetSet)
     swTable *table = swoole_get_object(getThis());
     if (table == NULL || table->memory == NULL)
     {
-        swoole_php_fatal_error(E_ERROR, "Must create table first.");
+        swoole_php_fatal_error(E_ERROR, "Must create table first");
         RETURN_FALSE;
     }
 
-    zval *zprop_key = sw_zend_read_property(swoole_table_row_ce_ptr, getThis(), ZEND_STRL("key"), 0);
+    zval *zprop_key = sw_zend_read_property(swoole_table_row_ce, getThis(), ZEND_STRL("key"), 0);
 
     swTableRow *_rowlock = NULL;
     swTableRow *row = swTableRow_set(table, Z_STRVAL_P(zprop_key), Z_STRLEN_P(zprop_key), &_rowlock);
     if (!row)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_error(E_WARNING, "Unable to allocate memory.");
+        swoole_php_error(E_WARNING, "Unable to allocate memory");
         RETURN_FALSE;
     }
 
@@ -892,7 +894,7 @@ static PHP_METHOD(swoole_table_row, offsetSet)
     if (col == NULL)
     {
         swTableRow_unlock(_rowlock);
-        swoole_php_fatal_error(E_WARNING, "column[%s] does not exist.", key);
+        swoole_php_fatal_error(E_WARNING, "column[%s] does not exist", key);
         RETURN_FALSE;
     }
     if (col->type == SW_TABLE_STRING)
@@ -913,7 +915,7 @@ static PHP_METHOD(swoole_table_row, offsetSet)
     }
     swTableRow_unlock(_rowlock);
 
-    zval *zprop_value = sw_zend_read_property(swoole_table_row_ce_ptr, getThis(), ZEND_STRL("value"), 0);
+    zval *zprop_value = sw_zend_read_property(swoole_table_row_ce, getThis(), ZEND_STRL("value"), 0);
     Z_TRY_ADDREF_P(value);
     add_assoc_zval_ex(zprop_value, key, keylen, value);
 
@@ -922,13 +924,13 @@ static PHP_METHOD(swoole_table_row, offsetSet)
 
 static PHP_METHOD(swoole_table_row, offsetUnset)
 {
-    swoole_php_fatal_error(E_WARNING, "not supported.");
+    swoole_php_fatal_error(E_WARNING, "not supported");
     RETURN_FALSE;
 }
 
 static PHP_METHOD(swoole_table_row, __destruct)
 {
-    SW_PREVENT_USER_DESTRUCT;
+    SW_PREVENT_USER_DESTRUCT();
 
     swoole_set_object(getThis(), NULL);
 }
