@@ -156,14 +156,14 @@ class OpcodeServer
     public function onTask(\swoole_server $swooleServer, $taskId, $fromWorkerId, $recv)
     {
         $recv = json_decode($recv);
-        assert(json_last_error() === JSON_ERROR_NONE);
+        Assert::eq(json_last_error(), JSON_ERROR_NONE);
         return json_encode($recv);
     }
 
     public function onFinish(\swoole_server $swooleServer, $taskId, $recv)
     {
         $recv = json_decode($recv);
-        assert(json_last_error() === JSON_ERROR_NONE);
+        Assert::eq(json_last_error(), JSON_ERROR_NONE);
         assert(isset($recv["fd"]) && isset($recv["data"]));
         $this->swooleServer->send($recv["fd"], opcode_encode("return", $recv["data"]));
     }
@@ -171,7 +171,7 @@ class OpcodeServer
     public function onPipeMessage(\swoole_server $swooleServer, $fromWorkerId, $recv)
     {
         $recv = json_decode($recv, true);
-        assert(json_last_error() === JSON_ERROR_NONE);
+        Assert::eq(json_last_error(), JSON_ERROR_NONE);
         assert(isset($recv["fd"]) && isset($recv["msg"]));
         $this->swooleServer->send($recv["fd"], opcode_encode("return", $recv["msg"]));
     }
